@@ -1,7 +1,7 @@
-msAbund <- function(formula, data, inits, priors, tuning, 
+msAbund <- function(formula, data, inits, priors, tuning,
 		    n.batch, batch.length, accept.rate = 0.43, family = 'Poisson',
-		    n.omp.threads = 1, verbose = TRUE, n.report = 100, 
-		    n.burn = round(.10 * n.batch * batch.length), n.thin = 1, 
+		    n.omp.threads = 1, verbose = TRUE, n.report = 100,
+		    n.burn = round(.10 * n.batch * batch.length), n.thin = 1,
 		    n.chains = 1, save.fitted = TRUE, ...){
 
   ptm <- proc.time()
@@ -11,7 +11,7 @@ msAbund <- function(formula, data, inits, priors, tuning,
   }
   if (family %in% c('Gaussian', 'zi-Gaussian')) {
     msAbundGaussian(formula, data, inits, priors, tuning, n.batch,
-                    batch.length, accept.rate, family, n.omp.threads, 
+                    batch.length, accept.rate, family, n.omp.threads,
                     verbose, n.report, n.burn, n.thin, n.chains, save.fitted)
   } else {
 
@@ -21,14 +21,14 @@ msAbund <- function(formula, data, inits, priors, tuning,
     rigamma <- function(n, a, b){
       1/rgamma(n = n, shape = a, rate = b)
     }
- 
+
     # Make it look nice
     if (verbose) {
       cat("----------------------------------------\n");
       cat("\tPreparing to run the model\n");
       cat("----------------------------------------\n");
     }
-    # Check for unused arguments ------------------------------------------	
+    # Check for unused arguments ------------------------------------------
     formal.args <- names(formals(sys.function(sys.parent())))
     elip.args <- names(list(...))
     for(i in elip.args){
@@ -36,8 +36,8 @@ msAbund <- function(formula, data, inits, priors, tuning,
             warning("'",i, "' is not an argument")
     }
     # Call ----------------------------------------------------------------
-    # Returns a call in which all of the specified arguments are 
-    # specified by their full names. 
+    # Returns a call in which all of the specified arguments are
+    # specified by their full names.
     cl <- match.call()
 
     # Some initial checks -------------------------------------------------
@@ -47,6 +47,9 @@ msAbund <- function(formula, data, inits, priors, tuning,
     if (!is.list(data)) {
       stop("error: data must be a list")
     }
+    # Create a copy of input data, which takes up some space, but allows for
+    # updateMCMC() to work.
+    data.orig <- data
     names(data) <- tolower(names(data))
     if (!'y' %in% names(data)) {
       stop("error: count data y must be specified in data")
@@ -92,17 +95,17 @@ msAbund <- function(formula, data, inits, priors, tuning,
     if ('offset' %in% names(data)) {
       offset <- data$offset
       if (length(offset) == 1) {
-        offset <- matrix(offset, ncol(y), dim(y)[3]) 
+        offset <- matrix(offset, ncol(y), dim(y)[3])
       } else if (length(dim(offset)) == 1) { # Value for each site
         if (length(offset) != ncol(y)) {
-          stop(paste0("offset must be a single value, vector of length ", ncol(y), " or a matrix with ", 
-                     ncol(y), " rows and ", dim(y)[3], " columns."))	
+          stop(paste0("offset must be a single value, vector of length ", ncol(y), " or a matrix with ",
+                     ncol(y), " rows and ", dim(y)[3], " columns."))
         }
         offset <- matrix(offset, ncol(y), dim(y)[3])
       } else if (length(dim(offset)) == 2) { # Value for each site/obs
         if (nrow(offset) != ncol(y) | ncol(offset) != dim(y)[3]) {
-          stop(paste0("offset must be a single value, vector of length ", ncol(y), " or a matrix with ", 
-                      ncol(y), " rows and ", dim(y)[3], " columns."))	
+          stop(paste0("offset must be a single value, vector of length ", ncol(y), " or a matrix with ",
+                      ncol(y), " rows and ", dim(y)[3], " columns."))
 
         }
       }
@@ -111,7 +114,7 @@ msAbund <- function(formula, data, inits, priors, tuning,
     }
     offset.mat <- offset
 
-    # First subset covariates to only use those that are included in the analysis. 
+    # First subset covariates to only use those that are included in the analysis.
     # Get occurrence covariates in proper format
     # Subset covariates to only use those that are included in the analysis
     data$covs <- data$covs[names(data$covs) %in% all.vars(formula)]
@@ -127,14 +130,14 @@ msAbund <- function(formula, data, inits, priors, tuning,
     }
 
     # Check whether random effects are sent in as numeric, and
-    # return error if they are. 
+    # return error if they are.
     # Abundance -------------------------
     if (!is.null(findbars(formula))) {
       abund.re.names <- unique(unlist(sapply(findbars(formula), all.vars)))
       for (i in 1:length(abund.re.names)) {
         if (is(data$covs[, abund.re.names[i]], 'factor')) {
           stop(paste("error: random effect variable ", abund.re.names[i], " specified as a factor. Random effect variables must be specified as numeric.", sep = ''))
-        } 
+        }
         if (is(data$covs[, abund.re.names[i]], 'character')) {
           stop(paste("error: random effect variable ", abund.re.names[i], " specified as character. Random effect variables must be specified as numeric.", sep = ''))
         }
@@ -149,9 +152,9 @@ msAbund <- function(formula, data, inits, priors, tuning,
     }
     # covs ------------------------
     for (i in 1:ncol(data$covs)) {
-      # Note that this assumes the same detection history for each species.  
+      # Note that this assumes the same detection history for each species.
       if (sum(is.na(data$covs[, i])) > sum(is.na(y.mat[1, , ]))) {
-        stop("error: some elements in covs have missing values where there is an observed data value in y. Please either replace the NA values in covs with non-missing values (e.g., mean imputation) or set the corresponding values in y to NA where the covariate is missing.") 
+        stop("error: some elements in covs have missing values where there is an observed data value in y. Please either replace the NA values in covs with non-missing values (e.g., mean imputation) or set the corresponding values in y to NA where the covariate is missing.")
       }
     }
     # Misalignment between y and covs
@@ -195,9 +198,9 @@ msAbund <- function(formula, data, inits, priors, tuning,
     x.re.names <- x.random.names
 
     # Extract data from inputs --------------------------------------------
-    # Number of species 
+    # Number of species
     n.sp <- dim(y)[1]
-    # Number of abundance parameters 
+    # Number of abundance parameters
     p.abund <- ncol(X)
     # Number of abundance random effect parameters
     p.abund.re <- ncol(X.re)
@@ -207,25 +210,25 @@ msAbund <- function(formula, data, inits, priors, tuning,
     # Number of sites
     J <- ncol(y)
     # Number of replicate surveys
-    # Note this assumes equivalent detection histories for all species. 
-    # May want to change this at some point. 
+    # Note this assumes equivalent detection histories for all species.
+    # May want to change this at some point.
     n.rep <- apply(y.mat[1, , , drop = FALSE], 2, function(a) sum(!is.na(a)))
     K.max <- dim(y.mat)[3]
     # Because I like K better than n.rep
     K <- n.rep
 
     # Get indices to map N to y -------------------------------------------
-    site.indx <- rep(1:J, dim(y.mat)[3]) 
+    site.indx <- rep(1:J, dim(y.mat)[3])
     site.indx <- site.indx[!is.na(c(y.mat[1, , ]))]
     # Subtract 1 for indices in C
     site.indx <- site.indx - 1
     # y is stored in the following order: species, site, visit
     y <- c(y)
     offset <- c(offset)
-    # Assumes the missing data are constant across species, which seems likely, 
-    # but may eventually need some updating. 
+    # Assumes the missing data are constant across species, which seems likely,
+    # but may eventually need some updating.
     names.long <- which(!is.na(c(y.mat[1, , ])))
-    # Only need to check this when there are observation level covariates. 
+    # Only need to check this when there are observation level covariates.
     if (nrow(X) == length(y) / n.sp) {
       X <- X[!is.na(c(y.mat[1, , ])), , drop = FALSE]
     }
@@ -292,7 +295,7 @@ msAbund <- function(formula, data, inits, priors, tuning,
       }
       mu.beta.comm <- rep(0, p.abund)
       sigma.beta.comm <- rep(100, p.abund)
-      Sigma.beta.comm <- diag(p.abund) * 100 
+      Sigma.beta.comm <- diag(p.abund) * 100
     }
 
     # tau.sq.beta -----------------------
@@ -304,19 +307,19 @@ msAbund <- function(formula, data, inits, priors, tuning,
       tau.sq.beta.b <- priors$tau.sq.beta.ig[[2]]
       if (length(tau.sq.beta.a) != p.abund & length(tau.sq.beta.a) != 1) {
         if (p.abund == 1) {
-          stop(paste("error: tau.sq.beta.ig[[1]] must be a vector of length ", 
+          stop(paste("error: tau.sq.beta.ig[[1]] must be a vector of length ",
         	   p.abund, " with elements corresponding to tau.sq.betas' shape", sep = ""))
         } else {
-          stop(paste("error: tau.sq.beta.ig[[1]] must be a vector of length ", 
+          stop(paste("error: tau.sq.beta.ig[[1]] must be a vector of length ",
         	   p.abund, " or 1 with elements corresponding to tau.sq.betas' shape", sep = ""))
         }
       }
       if (length(tau.sq.beta.b) != p.abund & length(tau.sq.beta.b) != 1) {
         if (p.abund == 1) {
-          stop(paste("error: tau.sq.beta.ig[[2]] must be a vector of length ", 
+          stop(paste("error: tau.sq.beta.ig[[2]] must be a vector of length ",
         	   p.abund, " with elements corresponding to tau.sq.betas' scale", sep = ""))
         } else {
-          stop(paste("error: tau.sq.beta.ig[[2]] must be a vector of length ", 
+          stop(paste("error: tau.sq.beta.ig[[2]] must be a vector of length ",
         	   p.abund, " or 1 with elements corresponding to tau.sq.betas' scale", sep = ""))
         }
       }
@@ -327,7 +330,7 @@ msAbund <- function(formula, data, inits, priors, tuning,
         tau.sq.beta.b <- rep(tau.sq.beta.b, p.abund)
       }
     } else {
-      if (verbose) {	    
+      if (verbose) {
         message("No prior specified for tau.sq.beta.ig.\nSetting prior shape to 0.1 and prior scale to 0.1\n")
       }
       tau.sq.beta.a <- rep(0.1, p.abund)
@@ -343,19 +346,19 @@ msAbund <- function(formula, data, inits, priors, tuning,
         sigma.sq.mu.b <- priors$sigma.sq.mu.ig[[2]]
         if (length(sigma.sq.mu.a) != p.abund.re & length(sigma.sq.mu.a) != 1) {
           if (p.abund.re == 1) {
-          stop(paste("error: sigma.sq.mu.ig[[1]] must be a vector of length ", 
+          stop(paste("error: sigma.sq.mu.ig[[1]] must be a vector of length ",
           	   p.abund.re, " with elements corresponding to sigma.sq.mus' shape", sep = ""))
           } else {
-          stop(paste("error: sigma.sq.mu.ig[[1]] must be a vector of length ", 
+          stop(paste("error: sigma.sq.mu.ig[[1]] must be a vector of length ",
           	   p.abund.re, " or 1 with elements corresponding to sigma.sq.mus' shape", sep = ""))
           }
         }
         if (length(sigma.sq.mu.b) != p.abund.re & length(sigma.sq.mu.b) != 1) {
           if (p.abund.re == 1) {
-            stop(paste("error: sigma.sq.mu.ig[[2]] must be a vector of length ", 
+            stop(paste("error: sigma.sq.mu.ig[[2]] must be a vector of length ",
           	   p.abund.re, " with elements corresponding to sigma.sq.mus' scale", sep = ""))
           } else {
-            stop(paste("error: sigma.sq.mu.ig[[2]] must be a vector of length ", 
+            stop(paste("error: sigma.sq.mu.ig[[2]] must be a vector of length ",
           	   p.abund.re, " or 1with elements corresponding to sigma.sq.mus' scale", sep = ""))
           }
         }
@@ -366,7 +369,7 @@ msAbund <- function(formula, data, inits, priors, tuning,
           sigma.sq.mu.b <- rep(sigma.sq.mu.b, p.abund.re)
         }
     }   else {
-        if (verbose) {	    
+        if (verbose) {
           message("No prior specified for sigma.sq.mu.ig.\nSetting prior shape to 0.1 and prior scale to 0.1\n")
         }
         sigma.sq.mu.a <- rep(0.1, p.abund.re)
@@ -385,11 +388,11 @@ msAbund <- function(formula, data, inits, priors, tuning,
         kappa.a <- priors$kappa.unif[[1]]
         kappa.b <- priors$kappa.unif[[2]]
         if (length(kappa.a) != n.sp & length(kappa.a) != 1) {
-          stop(paste("error: kappa.unif[[1]] must be a vector of length ", 
+          stop(paste("error: kappa.unif[[1]] must be a vector of length ",
           	   n.sp, " or 1 with elements corresponding to kappas' lower bound for each species", sep = ""))
         }
         if (length(kappa.b) != n.sp & length(kappa.b) != 1) {
-          stop(paste("error: kappa.unif[[2]] must be a vector of length ", 
+          stop(paste("error: kappa.unif[[2]] must be a vector of length ",
           	   n.sp, " or 1 with elements corresponding to kappas' upper bound for each species", sep = ""))
         }
         if (length(kappa.a) != n.sp) {
@@ -420,10 +423,10 @@ msAbund <- function(formula, data, inits, priors, tuning,
       beta.comm.inits <- inits[["beta.comm"]]
       if (length(beta.comm.inits) != p.abund & length(beta.comm.inits) != 1) {
         if (p.abund == 1) {
-          stop(paste("error: initial values for beta.comm must be of length ", p.abund, 
+          stop(paste("error: initial values for beta.comm must be of length ", p.abund,
         	   sep = ""))
         } else {
-          stop(paste("error: initial values for beta.comm must be of length ", p.abund, 
+          stop(paste("error: initial values for beta.comm must be of length ", p.abund,
         	   , " or 1", sep = ""))
         }
       }
@@ -441,10 +444,10 @@ msAbund <- function(formula, data, inits, priors, tuning,
       tau.sq.beta.inits <- inits[["tau.sq.beta"]]
       if (length(tau.sq.beta.inits) != p.abund & length(tau.sq.beta.inits) != 1) {
         if (p.abund == 1) {
-          stop(paste("error: initial values for tau.sq.beta must be of length ", p.abund, 
+          stop(paste("error: initial values for tau.sq.beta must be of length ", p.abund,
         	   sep = ""))
         } else {
-          stop(paste("error: initial values for tau.sq.beta must be of length ", p.abund, 
+          stop(paste("error: initial values for tau.sq.beta must be of length ", p.abund,
         	   " or 1", sep = ""))
         }
       }
@@ -462,12 +465,12 @@ msAbund <- function(formula, data, inits, priors, tuning,
       beta.inits <- inits[["beta"]]
       if (is.matrix(beta.inits)) {
         if (ncol(beta.inits) != p.abund | nrow(beta.inits) != n.sp) {
-          stop(paste("error: initial values for beta must be a matrix with dimensions ", 
+          stop(paste("error: initial values for beta must be a matrix with dimensions ",
           	   n.sp, "x", p.abund, " or a single numeric value", sep = ""))
         }
       }
       if (!is.matrix(beta.inits) & length(beta.inits) != 1) {
-        stop(paste("error: initial values for beta must be a matrix with dimensions ", 
+        stop(paste("error: initial values for beta must be a matrix with dimensions ",
         	   n.sp, " x ", p.abund, " or a single numeric value", sep = ""))
       }
       if (length(beta.inits) == 1) {
@@ -485,15 +488,15 @@ msAbund <- function(formula, data, inits, priors, tuning,
         sigma.sq.mu.inits <- inits[["sigma.sq.mu"]]
         if (length(sigma.sq.mu.inits) != p.abund.re & length(sigma.sq.mu.inits) != 1) {
           if (p.abund.re == 1) {
-            stop(paste("error: initial values for sigma.sq.mu must be of length ", p.abund.re, 
+            stop(paste("error: initial values for sigma.sq.mu must be of length ", p.abund.re,
         	     sep = ""))
           } else {
-            stop(paste("error: initial values for sigma.sq.mu must be of length ", p.abund.re, 
+            stop(paste("error: initial values for sigma.sq.mu must be of length ", p.abund.re,
         	     " or 1", sep = ""))
           }
         }
         if (length(sigma.sq.mu.inits) != p.abund.re) {
-          sigma.sq.mu.inits <- rep(sigma.sq.mu.inits, p.abund.re)  
+          sigma.sq.mu.inits <- rep(sigma.sq.mu.inits, p.abund.re)
         }
       } else {
         sigma.sq.mu.inits <- runif(p.abund.re, 0.05, 1)
@@ -502,9 +505,17 @@ msAbund <- function(formula, data, inits, priors, tuning,
         }
       }
       beta.star.indx <- rep(0:(p.abund.re - 1), n.abund.re.long)
-      beta.star.inits <- rnorm(n.abund.re, sqrt(sigma.sq.mu.inits[beta.star.indx + 1]))
-      # Starting values for all species 
-      beta.star.inits <- rep(beta.star.inits, n.sp)
+      if ('beta.star' %in% names(inits)) {
+        beta.star.inits <- inits[['beta.star']]
+        if (length(beta.star.inits) !=  n.abund.re * n.sp) {
+          stop(paste0("initial values for beta.star must be of length ", n.abund.re * n.sp))
+	}
+      } else {
+        message("beta.star is not specified in initial values.\nSetting initial values from the prior.\n")
+        beta.star.inits <- rnorm(n.abund.re, sqrt(sigma.sq.mu.inits[beta.star.indx + 1]))
+        # Starting values for all species
+        beta.star.inits <- rep(beta.star.inits, n.sp)
+      }
     } else {
       sigma.sq.mu.inits <- 0
       beta.star.indx <- 0
@@ -516,7 +527,7 @@ msAbund <- function(formula, data, inits, priors, tuning,
       if ("kappa" %in% names(inits)) {
         kappa.inits <- inits[["kappa"]]
         if (length(kappa.inits) != n.sp & length(kappa.inits) != 1) {
-          stop(paste("error: initial values for kappa must be of length ", n.sp, " or 1", 
+          stop(paste("error: initial values for kappa must be of length ", n.sp, " or 1",
           	   sep = ""))
         }
         if (length(kappa.inits) != n.sp) {
@@ -557,9 +568,9 @@ msAbund <- function(formula, data, inits, priors, tuning,
       }
       beta.tuning <- tuning$beta
       if (length(beta.tuning) != 1 & length(beta.tuning) != p.abund * n.sp) {
-        stop(paste("error: beta tuning must be a single value or a vector of length ", 
+        stop(paste("error: beta tuning must be a single value or a vector of length ",
           	 p.abund * n.sp, sep = ''))
-      } 
+      }
       if (length(beta.tuning) == 1) {
         beta.tuning <- rep(beta.tuning, p.abund * n.sp)
       }
@@ -569,12 +580,15 @@ msAbund <- function(formula, data, inits, priors, tuning,
           stop("error: beta.star must be specified in tuning value list")
         }
         beta.star.tuning <- tuning$beta.star
-        if (length(beta.star.tuning) != 1) {
-          stop("error: beta.star tuning must be a single value")
-        } 
-        beta.star.tuning <- rep(beta.star.tuning, n.abund.re * n.sp)
+        if (length(beta.star.tuning) != 1 & length(beta.star.tuning) != n.abund.re * n.sp) {
+          stop(paste("error: beta.star tuning must be a single value or a vector of length ",
+            	 n.abund.re * n.sp, sep = ''))
+        }
+        if (length(beta.star.tuning) == 1) {
+          beta.star.tuning <- rep(beta.star.tuning, n.abund.re * n.sp)
+        }
       } else {
-        beta.star.tuning <- NULL 
+        beta.star.tuning <- NULL
       }
       # kappa ---------------------------
       if (family == 'NB') {
@@ -632,8 +646,8 @@ msAbund <- function(formula, data, inits, priors, tuning,
     storage.mode(n.report) <- "integer"
     chain.info <- c(curr.chain, n.chains)
     storage.mode(chain.info) <- "integer"
-    n.post.samples <- length(seq(from = n.burn + 1, 
-        			 to = n.samples, 
+    n.post.samples <- length(seq(from = n.burn + 1,
+        			 to = n.samples,
         			 by = as.integer(n.thin)))
     # samples.info order: burn-in, thinning rate, number of posterior samples
     samples.info <- c(n.burn, n.thin, n.post.samples)
@@ -655,12 +669,14 @@ msAbund <- function(formula, data, inits, priors, tuning,
     # Fit the model -------------------------------------------------------
     out.tmp <- list()
     out <- list()
+    # Random seed information for each chain of the model.
+    seeds.list <- list()
     for (i in 1:n.chains) {
       # Change initial values if i > 1
       if ((i > 1) & (!fix.inits)) {
         beta.comm.inits <- rnorm(p.abund, 0, 1)
         tau.sq.beta.inits <- runif(p.abund, 0.05, 1)
-        beta.inits <- matrix(rnorm(n.sp * p.abund, beta.comm.inits, 
+        beta.inits <- matrix(rnorm(n.sp * p.abund, beta.comm.inits,
               		     sqrt(tau.sq.beta.inits)), n.sp, p.abund)
         if (family == 'NB') {
           kappa.inits <- runif(n.sp, kappa.a, kappa.b)
@@ -673,40 +689,41 @@ msAbund <- function(formula, data, inits, priors, tuning,
       }
 
       storage.mode(chain.info) <- "integer"
-      out.tmp[[i]] <- .Call("msAbund", y, X, X.re, X.random, consts, n.abund.re.long, 
-        		    beta.inits, kappa.inits, beta.comm.inits, 
-        	            tau.sq.beta.inits, sigma.sq.mu.inits, beta.star.inits, site.indx, 
-        		    beta.star.indx, beta.level.indx,  
-        		    mu.beta.comm, Sigma.beta.comm, kappa.a, 
-          		    kappa.b, tau.sq.beta.a, tau.sq.beta.b,  
+      out.tmp[[i]] <- .Call("msAbund", y, X, X.re, X.random, consts, n.abund.re.long,
+        		    beta.inits, kappa.inits, beta.comm.inits,
+        	            tau.sq.beta.inits, sigma.sq.mu.inits, beta.star.inits, site.indx,
+        		    beta.star.indx, beta.level.indx,
+        		    mu.beta.comm, Sigma.beta.comm, kappa.a,
+          		    kappa.b, tau.sq.beta.a, tau.sq.beta.b,
         		    sigma.sq.mu.a, sigma.sq.mu.b,
-      	                    tuning.c, n.batch, batch.length, accept.rate, n.omp.threads, 
+      	                    tuning.c, n.batch, batch.length, accept.rate, n.omp.threads,
       	                    verbose, n.report, samples.info, chain.info, family.c, offset)
       chain.info[1] <- chain.info[1] + 1
+      seeds.list[[i]] <- .Random.seed
     }
     # Calculate R-Hat ---------------
     out <- list()
     out$rhat <- list()
     if (n.chains > 1) {
-      # as.vector removes the "Upper CI" when there is only 1 variable. 
-      out$rhat$beta.comm <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a) 
-      					      mcmc(t(a$beta.comm.samples)))), 
-      			     autoburnin = FALSE)$psrf[, 2])
-      out$rhat$tau.sq.beta <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a) 
-      					      mcmc(t(a$tau.sq.beta.samples)))), 
-      			     autoburnin = FALSE)$psrf[, 2])
-      out$rhat$beta <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a) 
-      					         mcmc(t(a$beta.samples)))), 
-      			     autoburnin = FALSE)$psrf[, 2])
+      # as.vector removes the "Upper CI" when there is only 1 variable.
+      out$rhat$beta.comm <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a)
+      					      mcmc(t(a$beta.comm.samples)))),
+      			     autoburnin = FALSE, multivariate = FALSE)$psrf[, 2])
+      out$rhat$tau.sq.beta <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a)
+      					      mcmc(t(a$tau.sq.beta.samples)))),
+      			     autoburnin = FALSE, multivariate = FALSE)$psrf[, 2])
+      out$rhat$beta <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a)
+      					         mcmc(t(a$beta.samples)))),
+      			     autoburnin = FALSE, multivariate = FALSE)$psrf[, 2])
       if (family == 'NB') {
-        out$rhat$kappa <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a) 
-      					      mcmc(t(a$kappa.samples)))), 
-      			     autoburnin = FALSE)$psrf[, 2])
+        out$rhat$kappa <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a)
+      					      mcmc(t(a$kappa.samples)))),
+      			     autoburnin = FALSE, multivariate = FALSE)$psrf[, 2])
       }
       if (p.abund.re > 0) {
-        out$rhat$sigma.sq.mu <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a) 
-        					      mcmc(t(a$sigma.sq.mu.samples)))), 
-        			     autoburnin = FALSE)$psrf[, 2])
+        out$rhat$sigma.sq.mu <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a)
+        					      mcmc(t(a$sigma.sq.mu.samples)))),
+        			     autoburnin = FALSE, multivariate = FALSE)$psrf[, 2])
       }
     } else {
       out$rhat$beta.comm <- rep(NA, p.abund)
@@ -720,7 +737,7 @@ msAbund <- function(formula, data, inits, priors, tuning,
     # Put everything into MCMC objects
     out$beta.comm.samples <- mcmc(do.call(rbind, lapply(out.tmp, function(a) t(a$beta.comm.samples))))
     colnames(out$beta.comm.samples) <- x.names
-    out$tau.sq.beta.samples <- mcmc(do.call(rbind, 
+    out$tau.sq.beta.samples <- mcmc(do.call(rbind,
       				lapply(out.tmp, function(a) t(a$tau.sq.beta.samples))))
     colnames(out$tau.sq.beta.samples) <- x.names
 
@@ -732,11 +749,11 @@ msAbund <- function(formula, data, inits, priors, tuning,
     colnames(out$beta.samples) <- coef.names
     if (family == 'NB') {
       out$kappa.samples <- mcmc(do.call(rbind, lapply(out.tmp, function(a) t(a$kappa.samples))))
-      colnames(out$kappa.samples) <- paste('kappa', sp.names, sep = '-') 
+      colnames(out$kappa.samples) <- paste('kappa', sp.names, sep = '-')
     }
     y.non.miss.indx <- which(!is.na(y.mat), arr.ind = TRUE)
     if (save.fitted) {
-      out$y.rep.samples <- do.call(abind, lapply(out.tmp, function(a) array(a$y.rep.samples, 
+      out$y.rep.samples <- do.call(abind, lapply(out.tmp, function(a) array(a$y.rep.samples,
         								dim = c(n.sp * n.obs, n.post.samples))))
       tmp <- array(NA, dim = c(n.post.samples * n.chains, n.sp, J, K.max))
       for (j in 1:(n.obs * n.sp)) {
@@ -744,7 +761,7 @@ msAbund <- function(formula, data, inits, priors, tuning,
         tmp[, curr.indx[1], curr.indx[2], curr.indx[3]] <- out$y.rep.samples[j, ]
       }
       out$y.rep.samples <- tmp
-      out$mu.samples <- do.call(abind, lapply(out.tmp, function(a) array(a$mu.samples, 
+      out$mu.samples <- do.call(abind, lapply(out.tmp, function(a) array(a$mu.samples,
         								dim = c(n.sp * n.obs, n.post.samples))))
       tmp <- array(NA, dim = c(n.post.samples * n.chains, n.sp, J, K.max))
       for (j in 1:(n.obs * n.sp)) {
@@ -752,7 +769,7 @@ msAbund <- function(formula, data, inits, priors, tuning,
         tmp[, curr.indx[1], curr.indx[2], curr.indx[3]] <- out$mu.samples[j, ]
       }
       out$mu.samples <- tmp
-      out$like.samples <- do.call(abind, lapply(out.tmp, function(a) array(a$like.samples, 
+      out$like.samples <- do.call(abind, lapply(out.tmp, function(a) array(a$like.samples,
         								dim = c(n.sp * n.obs, n.post.samples))))
       tmp <- array(NA, dim = c(n.post.samples * n.chains, n.sp, J, K.max))
       for (j in 1:(n.obs * n.sp)) {
@@ -807,13 +824,29 @@ msAbund <- function(formula, data, inits, priors, tuning,
     out$n.thin <- n.thin
     out$n.burn <- n.burn
     out$n.chains <- n.chains
-    out$dist <- family 
+    out$dist <- family
     out$re.cols <- re.cols
     if (p.abund.re > 0) {
       out$muRE <- TRUE
     } else {
       out$muRE <- FALSE
     }
+    # Send out objects needed for updateMCMC()
+    update.list <- list()
+    update.list$tuning <- matrix(NA, nrow(out.tmp[[1]]$tune), n.chains)
+    for (i in 1:n.chains) {
+      update.list$tuning[, i] <- exp(out.tmp[[i]]$tune[, n.batch])
+    }
+    update.list$accept.rate <- accept.rate
+    update.list$n.batch <- n.batch
+    update.list$batch.length <- batch.length
+    update.list$n.omp.threads <- n.omp.threads
+    update.list$data <- data.orig
+    update.list$priors <- priors
+    update.list$formula <- formula
+    # Random seed to have for updating.
+    update.list$final.seed <- seeds.list
+    out$update <- update.list
     class(out) <- "msAbund"
     out$run.time <- proc.time() - ptm
     out
