@@ -1,7 +1,7 @@
-msNMix <- function(abund.formula, det.formula, data, inits, priors,  
-		   tuning, n.batch, batch.length, accept.rate = 0.43, family = 'Poisson', 
-		   n.omp.threads = 1, verbose = TRUE, n.report = 100, 
-		   n.burn = round(.10 * n.samples), n.thin = 1, 
+msNMix <- function(abund.formula, det.formula, data, inits, priors,
+		   tuning, n.batch, batch.length, accept.rate = 0.43, family = 'Poisson',
+		   n.omp.threads = 1, verbose = TRUE, n.report = 100,
+		   n.burn = round(.10 * n.samples), n.thin = 1,
 		   n.chains = 1, ...){
 
   ptm <- proc.time()
@@ -9,14 +9,14 @@ msNMix <- function(abund.formula, det.formula, data, inits, priors,
   # Functions -----------------------------------------------------------
   logit <- function(theta, a = 0, b = 1) {log((theta-a)/(b-theta))}
   logit.inv <- function(z, a = 0, b = 1) {b-(b-a)/(1+exp(z))}
- 
+
   # Make it look nice
   if (verbose) {
     cat("----------------------------------------\n");
     cat("\tPreparing to run the model\n");
     cat("----------------------------------------\n");
   }
-  # Check for unused arguments ------------------------------------------	
+  # Check for unused arguments ------------------------------------------
   formal.args <- names(formals(sys.function(sys.parent())))
   elip.args <- names(list(...))
   for(i in elip.args){
@@ -24,8 +24,8 @@ msNMix <- function(abund.formula, det.formula, data, inits, priors,
           warning("'",i, "' is not an argument")
   }
   # Call ----------------------------------------------------------------
-  # Returns a call in which all of the specified arguments are 
-  # specified by their full names. 
+  # Returns a call in which all of the specified arguments are
+  # specified by their full names.
   cl <- match.call()
 
   # Some initial checks -------------------------------------------------
@@ -94,28 +94,28 @@ msNMix <- function(abund.formula, det.formula, data, inits, priors,
     stop("error: n.thin must be less than n.samples")
   }
 
-  # First subset detection covariates to only use those that are included in the analysis. 
+  # First subset detection covariates to only use those that are included in the analysis.
   data$det.covs <- data$det.covs[names(data$det.covs) %in% all.vars(det.formula)]
   # Null model support
   if (length(data$det.covs) == 0) {
     data$det.covs <- list(int = rep(1, dim(y)[2]))
   }
   # Make both covariates a data frame. Unlist is necessary for when factors
-  # are supplied. 
+  # are supplied.
   data$det.covs <- data.frame(lapply(data$det.covs, function(a) unlist(c(a))))
   # Indicator of whether all det.covs are site level or not
-  site.level.ind <- ifelse(nrow(data$det.covs) == ncol(y), TRUE, FALSE) 
+  site.level.ind <- ifelse(nrow(data$det.covs) == ncol(y), TRUE, FALSE)
   data$abund.covs <- as.data.frame(data$abund.covs)
 
   # Check whether random effects are sent in as numeric, and
-  # return error if they are. 
+  # return error if they are.
   # Abundance -------------------------
   if (!is.null(findbars(abund.formula))) {
     abund.re.names <- unique(unlist(sapply(findbars(abund.formula), all.vars)))
     for (i in 1:length(abund.re.names)) {
       if (is(data$abund.covs[, abund.re.names[i]], 'factor')) {
         stop(paste("error: random effect variable ", abund.re.names[i], " specified as a factor. Random effect variables must be specified as numeric.", sep = ''))
-      } 
+      }
       if (is(data$abund.covs[, abund.re.names[i]], 'character')) {
         stop(paste("error: random effect variable ", abund.re.names[i], " specified as character. Random effect variables must be specified as numeric.", sep = ''))
       }
@@ -127,7 +127,7 @@ msNMix <- function(abund.formula, det.formula, data, inits, priors,
     for (i in 1:length(det.re.names)) {
       if (is(data$det.covs[, det.re.names[i]], 'factor')) {
         stop(paste("error: random effect variable ", det.re.names[i], " specified as a factor. Random effect variables must be specified as numeric.", sep = ''))
-      } 
+      }
       if (is(data$det.covs[, det.re.names[i]], 'character')) {
         stop(paste("error: random effect variable ", det.re.names[i], " specified as character. Random effect variables must be specified as numeric.", sep = ''))
       }
@@ -142,13 +142,13 @@ msNMix <- function(abund.formula, det.formula, data, inits, priors,
   }
   # abund.covs ------------------------
   if (sum(is.na(data$abund.covs)) != 0) {
-    stop("error: missing values in abund.covs. Please remove these sites from all objects in data or somehow replace the NA values with non-missing values (e.g., mean imputation).") 
+    stop("error: missing values in abund.covs. Please remove these sites from all objects in data or somehow replace the NA values with non-missing values (e.g., mean imputation).")
   }
   # det.covs ------------------------
   if (!site.level.ind) {
     for (i in 1:ncol(data$det.covs)) {
       if (sum(is.na(data$det.covs[, i])) > sum(is.na(y.mat[1, , ]))) {
-        stop("error: some elements in det.covs have missing values where there is an observed data value in y. Please either replace the NA values in det.covs with non-missing values (e.g., mean imputation) or set the corresponding values in y to NA where the covariate is missing.") 
+        stop("error: some elements in det.covs have missing values where there is an observed data value in y. Please either replace the NA values in det.covs with non-missing values (e.g., mean imputation) or set the corresponding values in y to NA where the covariate is missing.")
       }
     }
     # Misalignment between y and det.covs
@@ -166,7 +166,7 @@ msNMix <- function(abund.formula, det.formula, data, inits, priors,
   }
   if (site.level.ind) {
     if (sum(is.na(data$det.covs)) != 0) {
-      stop("missing values in site-level det.covs. Please remove these sites from all objects in data or somehow replace the NA values with non-missing values (e.g., mean imputation).") 
+      stop("missing values in site-level det.covs. Please remove these sites from all objects in data or somehow replace the NA values with non-missing values (e.g., mean imputation).")
     }
   }
 
@@ -218,9 +218,9 @@ msNMix <- function(abund.formula, det.formula, data, inits, priors,
   x.p.re.names <- x.p.random.names
 
   # Extract data from inputs --------------------------------------------
-  # Number of species 
+  # Number of species
   n.sp <- dim(y)[1]
-  # Number of abundance parameters 
+  # Number of abundance parameters
   p.abund <- ncol(X)
   # Number of abundance random effect parameters
   p.abund.re <- ncol(X.re)
@@ -238,8 +238,8 @@ msNMix <- function(abund.formula, det.formula, data, inits, priors,
   # Number of sites
   J <- nrow(X)
   # Number of repeat visits
-  # Note this assumes equivalent detection histories for all species. 
-  # May want to change this at some point. 
+  # Note this assumes equivalent detection histories for all species.
+  # May want to change this at some point.
   n.rep <- apply(y.mat[1, , , drop = FALSE], 2, function(a) sum(!is.na(a)))
   K.max <- dim(y.mat)[3]
   # Because I like K better than n.rep
@@ -247,14 +247,14 @@ msNMix <- function(abund.formula, det.formula, data, inits, priors,
 
   # Get indices to map N to y -------------------------------------------
   # N.long.indx <- rep(1:J, K.max)
-  N.long.indx <- rep(1:J, dim(y.mat)[3]) 
+  N.long.indx <- rep(1:J, dim(y.mat)[3])
   N.long.indx <- N.long.indx[!is.na(c(y.mat[1, , ]))]
   # Subtract 1 for indices in C
   N.long.indx <- N.long.indx - 1
   # y is stored in the following order: species, site, visit
   y <- c(y)
-  # Assumes the missing data are constant across species, which seems likely, 
-  # but may eventually need some updating. 
+  # Assumes the missing data are constant across species, which seems likely,
+  # but may eventually need some updating.
   names.long <- which(!is.na(c(y.mat[1, , ])))
   # Make necessary adjustment for site-level covariates only
   if (nrow(X.p) == J) {
@@ -263,9 +263,9 @@ msNMix <- function(abund.formula, det.formula, data, inits, priors,
     X.p.random <- X.p.random[N.long.indx + 1, , drop = FALSE]
   }
   # Remove missing observations when the covariate data are available but
-  # there are missing detection-nondetection data. 
+  # there are missing detection-nondetection data.
   if (nrow(X.p) == length(y) / n.sp) {
-    X.p <- X.p[!is.na(y.mat[1, , ]), , drop = FALSE]  
+    X.p <- X.p[!is.na(y.mat[1, , ]), , drop = FALSE]
   }
   if (nrow(X.p.re) == length(y) / n.sp & p.det.re > 0) {
     X.p.re <- X.p.re[!is.na(y.mat[1, , ]), , drop = FALSE]
@@ -333,7 +333,7 @@ msNMix <- function(abund.formula, det.formula, data, inits, priors,
     }
     mu.beta.comm <- rep(0, p.abund)
     sigma.beta.comm <- rep(100, p.abund)
-    Sigma.beta.comm <- diag(p.abund) * 100 
+    Sigma.beta.comm <- diag(p.abund) * 100
   }
 
   # alpha.comm -----------------------
@@ -386,19 +386,19 @@ msNMix <- function(abund.formula, det.formula, data, inits, priors,
     tau.sq.beta.b <- priors$tau.sq.beta.ig[[2]]
     if (length(tau.sq.beta.a) != p.abund & length(tau.sq.beta.a) != 1) {
       if (p.abund == 1) {
-        stop(paste("error: tau.sq.beta.ig[[1]] must be a vector of length ", 
+        stop(paste("error: tau.sq.beta.ig[[1]] must be a vector of length ",
       	   p.abund, " with elements corresponding to tau.sq.betas' shape", sep = ""))
       } else {
-        stop(paste("error: tau.sq.beta.ig[[1]] must be a vector of length ", 
+        stop(paste("error: tau.sq.beta.ig[[1]] must be a vector of length ",
       	   p.abund, " or 1 with elements corresponding to tau.sq.betas' shape", sep = ""))
       }
     }
     if (length(tau.sq.beta.b) != p.abund & length(tau.sq.beta.b) != 1) {
       if (p.abund == 1) {
-        stop(paste("error: tau.sq.beta.ig[[2]] must be a vector of length ", 
+        stop(paste("error: tau.sq.beta.ig[[2]] must be a vector of length ",
       	   p.abund, " with elements corresponding to tau.sq.betas' scale", sep = ""))
       } else {
-        stop(paste("error: tau.sq.beta.ig[[2]] must be a vector of length ", 
+        stop(paste("error: tau.sq.beta.ig[[2]] must be a vector of length ",
       	   p.abund, " or 1 with elements corresponding to tau.sq.betas' scale", sep = ""))
       }
     }
@@ -409,7 +409,7 @@ msNMix <- function(abund.formula, det.formula, data, inits, priors,
       tau.sq.beta.b <- rep(tau.sq.beta.b, p.abund)
     }
   } else {
-    if (verbose) {	    
+    if (verbose) {
       message("No prior specified for tau.sq.beta.ig.\nSetting prior shape to 0.1 and prior scale to 0.1\n")
     }
     tau.sq.beta.a <- rep(0.1, p.abund)
@@ -425,19 +425,19 @@ msNMix <- function(abund.formula, det.formula, data, inits, priors,
     tau.sq.alpha.b <- priors$tau.sq.alpha.ig[[2]]
     if (length(tau.sq.alpha.a) != p.det & length(tau.sq.alpha.a) != 1) {
       if (p.det == 1) {
-        stop(paste("error: tau.sq.alpha.ig[[1]] must be a vector of length ", 
+        stop(paste("error: tau.sq.alpha.ig[[1]] must be a vector of length ",
       	   p.det, " with elements corresponding to tau.sq.alphas' shape", sep = ""))
       } else {
-        stop(paste("error: tau.sq.alpha.ig[[1]] must be a vector of length ", 
+        stop(paste("error: tau.sq.alpha.ig[[1]] must be a vector of length ",
       	   p.det, " or 1 with elements corresponding to tau.sq.alphas' shape", sep = ""))
       }
     }
     if (length(tau.sq.alpha.b) != p.det & length(tau.sq.alpha.b) != 1) {
       if (p.det == 1) {
-        stop(paste("error: tau.sq.alpha.ig[[2]] must be a vector of length ", 
+        stop(paste("error: tau.sq.alpha.ig[[2]] must be a vector of length ",
       	   p.det, " with elements corresponding to tau.sq.alphas' scale", sep = ""))
       } else {
-        stop(paste("error: tau.sq.alpha.ig[[2]] must be a vector of length ", 
+        stop(paste("error: tau.sq.alpha.ig[[2]] must be a vector of length ",
       	   p.det, " or 1 with elements corresponding to tau.sq.alphas' scale", sep = ""))
       }
     }
@@ -448,7 +448,7 @@ msNMix <- function(abund.formula, det.formula, data, inits, priors,
       tau.sq.alpha.b <- rep(tau.sq.alpha.b, p.det)
     }
   } else {
-    if (verbose) {	    
+    if (verbose) {
       message("No prior specified for tau.sq.alpha.ig.\nSetting prior shape to 0.1 and prior scale to 0.1\n")
     }
     tau.sq.alpha.a <- rep(0.1, p.det)
@@ -464,19 +464,19 @@ msNMix <- function(abund.formula, det.formula, data, inits, priors,
       sigma.sq.mu.b <- priors$sigma.sq.mu.ig[[2]]
       if (length(sigma.sq.mu.a) != p.abund.re & length(sigma.sq.mu.a) != 1) {
         if (p.abund.re == 1) {
-        stop(paste("error: sigma.sq.mu.ig[[1]] must be a vector of length ", 
+        stop(paste("error: sigma.sq.mu.ig[[1]] must be a vector of length ",
         	   p.abund.re, " with elements corresponding to sigma.sq.mus' shape", sep = ""))
         } else {
-        stop(paste("error: sigma.sq.mu.ig[[1]] must be a vector of length ", 
+        stop(paste("error: sigma.sq.mu.ig[[1]] must be a vector of length ",
         	   p.abund.re, " or 1 with elements corresponding to sigma.sq.mus' shape", sep = ""))
         }
       }
       if (length(sigma.sq.mu.b) != p.abund.re & length(sigma.sq.mu.b) != 1) {
         if (p.abund.re == 1) {
-          stop(paste("error: sigma.sq.mu.ig[[2]] must be a vector of length ", 
+          stop(paste("error: sigma.sq.mu.ig[[2]] must be a vector of length ",
         	   p.abund.re, " with elements corresponding to sigma.sq.mus' scale", sep = ""))
         } else {
-          stop(paste("error: sigma.sq.mu.ig[[2]] must be a vector of length ", 
+          stop(paste("error: sigma.sq.mu.ig[[2]] must be a vector of length ",
         	   p.abund.re, " or 1with elements corresponding to sigma.sq.mus' scale", sep = ""))
         }
       }
@@ -487,7 +487,7 @@ msNMix <- function(abund.formula, det.formula, data, inits, priors,
         sigma.sq.mu.b <- rep(sigma.sq.mu.b, p.abund.re)
       }
   }   else {
-      if (verbose) {	    
+      if (verbose) {
         message("No prior specified for sigma.sq.mu.ig.\nSetting prior shape to 0.1 and prior scale to 0.1\n")
       }
       sigma.sq.mu.a <- rep(0.1, p.abund.re)
@@ -508,19 +508,19 @@ msNMix <- function(abund.formula, det.formula, data, inits, priors,
       sigma.sq.p.b <- priors$sigma.sq.p.ig[[2]]
       if (length(sigma.sq.p.a) != p.det.re & length(sigma.sq.p.a) != 1) {
         if (p.det.re == 1) {
-          stop(paste("error: sigma.sq.p.ig[[1]] must be a vector of length ", 
+          stop(paste("error: sigma.sq.p.ig[[1]] must be a vector of length ",
         	   p.det.re, " with elements corresponding to sigma.sq.ps' shape", sep = ""))
         } else {
-          stop(paste("error: sigma.sq.p.ig[[1]] must be a vector of length ", 
+          stop(paste("error: sigma.sq.p.ig[[1]] must be a vector of length ",
         	   p.det.re, " or 1 with elements corresponding to sigma.sq.ps' shape", sep = ""))
         }
       }
       if (length(sigma.sq.p.b) != p.det.re & length(sigma.sq.p.b) != 1) {
         if (p.det.re == 1) {
-          stop(paste("error: sigma.sq.p.ig[[2]] must be a vector of length ", 
+          stop(paste("error: sigma.sq.p.ig[[2]] must be a vector of length ",
         	     p.det.re, " with elements corresponding to sigma.sq.ps' scale", sep = ""))
         } else {
-          stop(paste("error: sigma.sq.p.ig[[2]] must be a vector of length ", 
+          stop(paste("error: sigma.sq.p.ig[[2]] must be a vector of length ",
         	     p.det.re, " or 1 with elements corresponding to sigma.sq.ps' scale", sep = ""))
         }
       }
@@ -531,7 +531,7 @@ msNMix <- function(abund.formula, det.formula, data, inits, priors,
         sigma.sq.p.b <- rep(sigma.sq.p.b, p.det.re)
       }
   }   else {
-      if (verbose) {	    
+      if (verbose) {
         message("No prior specified for sigma.sq.p.ig.\nSetting prior shape to 0.1 and prior scale to 0.1\n")
       }
       sigma.sq.p.a <- rep(0.1, p.det.re)
@@ -550,11 +550,11 @@ msNMix <- function(abund.formula, det.formula, data, inits, priors,
       kappa.a <- priors$kappa.unif[[1]]
       kappa.b <- priors$kappa.unif[[2]]
       if (length(kappa.a) != n.sp & length(kappa.a) != 1) {
-        stop(paste("error: kappa.unif[[1]] must be a vector of length ", 
+        stop(paste("error: kappa.unif[[1]] must be a vector of length ",
         	   n.sp, " or 1 with elements corresponding to kappas' lower bound for each species", sep = ""))
       }
       if (length(kappa.b) != n.sp & length(kappa.b) != 1) {
-        stop(paste("error: kappa.unif[[2]] must be a vector of length ", 
+        stop(paste("error: kappa.unif[[2]] must be a vector of length ",
         	   n.sp, " or 1 with elements corresponding to kappas' upper bound for each species", sep = ""))
       }
       if (length(kappa.a) != n.sp) {
@@ -584,11 +584,11 @@ msNMix <- function(abund.formula, det.formula, data, inits, priors,
   if ("n" %in% names(inits)) {
     N.inits <- inits$n
     if (!is.matrix(N.inits)) {
-      stop(paste("error: initial values for N must be a matrix with dimensions ", 
+      stop(paste("error: initial values for N must be a matrix with dimensions ",
       	   n.sp, " x ", J, sep = ""))
     }
     if (nrow(N.inits) != n.sp | ncol(N.inits) != J) {
-      stop(paste("error: initial values for N must be a matrix with dimensions ", 
+      stop(paste("error: initial values for N must be a matrix with dimensions ",
       	   n.sp, " x ", J, sep = ""))
     }
     N.test <- apply(y.mat, c(1, 2), max, na.rm = TRUE)
@@ -607,10 +607,10 @@ msNMix <- function(abund.formula, det.formula, data, inits, priors,
     beta.comm.inits <- inits[["beta.comm"]]
     if (length(beta.comm.inits) != p.abund & length(beta.comm.inits) != 1) {
       if (p.abund == 1) {
-        stop(paste("error: initial values for beta.comm must be of length ", p.abund, 
+        stop(paste("error: initial values for beta.comm must be of length ", p.abund,
       	   sep = ""))
       } else {
-        stop(paste("error: initial values for beta.comm must be of length ", p.abund, 
+        stop(paste("error: initial values for beta.comm must be of length ", p.abund,
       	   , " or 1", sep = ""))
       }
     }
@@ -628,10 +628,10 @@ msNMix <- function(abund.formula, det.formula, data, inits, priors,
     alpha.comm.inits <- inits[["alpha.comm"]]
     if (length(alpha.comm.inits) != p.det & length(alpha.comm.inits) != 1) {
       if (p.det == 1) {
-        stop(paste("error: initial values for alpha.comm must be of length ", p.det, 
+        stop(paste("error: initial values for alpha.comm must be of length ", p.det,
       	   sep = ""))
       } else {
-        stop(paste("error: initial values for alpha.comm must be of length ", p.det, 
+        stop(paste("error: initial values for alpha.comm must be of length ", p.det,
       	   , " or 1", sep = ""))
       }
     }
@@ -649,10 +649,10 @@ msNMix <- function(abund.formula, det.formula, data, inits, priors,
     tau.sq.beta.inits <- inits[["tau.sq.beta"]]
     if (length(tau.sq.beta.inits) != p.abund & length(tau.sq.beta.inits) != 1) {
       if (p.abund == 1) {
-        stop(paste("error: initial values for tau.sq.beta must be of length ", p.abund, 
+        stop(paste("error: initial values for tau.sq.beta must be of length ", p.abund,
       	   sep = ""))
       } else {
-        stop(paste("error: initial values for tau.sq.beta must be of length ", p.abund, 
+        stop(paste("error: initial values for tau.sq.beta must be of length ", p.abund,
       	   " or 1", sep = ""))
       }
     }
@@ -670,10 +670,10 @@ msNMix <- function(abund.formula, det.formula, data, inits, priors,
     tau.sq.alpha.inits <- inits[["tau.sq.alpha"]]
     if (length(tau.sq.alpha.inits) != p.det & length(tau.sq.alpha.inits) != 1) {
       if (p.det == 1) {
-        stop(paste("error: initial values for tau.sq.alpha must be of length ", p.det, 
+        stop(paste("error: initial values for tau.sq.alpha must be of length ", p.det,
       	   sep = ""))
       } else {
-        stop(paste("error: initial values for tau.sq.alpha must be of length ", p.det, 
+        stop(paste("error: initial values for tau.sq.alpha must be of length ", p.det,
       	   " or 1", sep = ""))
       }
     }
@@ -691,12 +691,12 @@ msNMix <- function(abund.formula, det.formula, data, inits, priors,
     beta.inits <- inits[["beta"]]
     if (is.matrix(beta.inits)) {
       if (ncol(beta.inits) != p.abund | nrow(beta.inits) != n.sp) {
-        stop(paste("error: initial values for beta must be a matrix with dimensions ", 
+        stop(paste("error: initial values for beta must be a matrix with dimensions ",
         	   n.sp, "x", p.abund, " or a single numeric value", sep = ""))
       }
     }
     if (!is.matrix(beta.inits) & length(beta.inits) != 1) {
-      stop(paste("error: initial values for beta must be a matrix with dimensions ", 
+      stop(paste("error: initial values for beta must be a matrix with dimensions ",
       	   n.sp, " x ", p.abund, " or a single numeric value", sep = ""))
     }
     if (length(beta.inits) == 1) {
@@ -713,12 +713,12 @@ msNMix <- function(abund.formula, det.formula, data, inits, priors,
     alpha.inits <- inits[["alpha"]]
     if (is.matrix(alpha.inits)) {
       if (ncol(alpha.inits) != p.det | nrow(alpha.inits) != n.sp) {
-        stop(paste("error: initial values for alpha must be a matrix with dimensions ", 
+        stop(paste("error: initial values for alpha must be a matrix with dimensions ",
         	   n.sp, "x", p.det, " or a single numeric value", sep = ""))
       }
     }
     if (!is.matrix(alpha.inits) & length(alpha.inits) != 1) {
-      stop(paste("error: initial values for alpha must be a matrix with dimensions ", 
+      stop(paste("error: initial values for alpha must be a matrix with dimensions ",
       	   n.sp, " x ", p.det, " or a single numeric value", sep = ""))
     }
     if (length(alpha.inits) == 1) {
@@ -736,15 +736,15 @@ msNMix <- function(abund.formula, det.formula, data, inits, priors,
       sigma.sq.mu.inits <- inits[["sigma.sq.mu"]]
       if (length(sigma.sq.mu.inits) != p.abund.re & length(sigma.sq.mu.inits) != 1) {
         if (p.abund.re == 1) {
-          stop(paste("error: initial values for sigma.sq.mu must be of length ", p.abund.re, 
+          stop(paste("error: initial values for sigma.sq.mu must be of length ", p.abund.re,
       	     sep = ""))
         } else {
-          stop(paste("error: initial values for sigma.sq.mu must be of length ", p.abund.re, 
+          stop(paste("error: initial values for sigma.sq.mu must be of length ", p.abund.re,
       	     " or 1", sep = ""))
         }
       }
       if (length(sigma.sq.mu.inits) != p.abund.re) {
-        sigma.sq.mu.inits <- rep(sigma.sq.mu.inits, p.abund.re)  
+        sigma.sq.mu.inits <- rep(sigma.sq.mu.inits, p.abund.re)
       }
     } else {
       sigma.sq.mu.inits <- runif(p.abund.re, 0.05, 1)
@@ -754,7 +754,7 @@ msNMix <- function(abund.formula, det.formula, data, inits, priors,
     }
     beta.star.indx <- rep(0:(p.abund.re - 1), n.abund.re.long)
     beta.star.inits <- rnorm(n.abund.re, sqrt(sigma.sq.mu.inits[beta.star.indx + 1]))
-    # Starting values for all species 
+    # Starting values for all species
     beta.star.inits <- rep(beta.star.inits, n.sp)
   } else {
     sigma.sq.mu.inits <- 0
@@ -767,10 +767,10 @@ msNMix <- function(abund.formula, det.formula, data, inits, priors,
       sigma.sq.p.inits <- inits[["sigma.sq.p"]]
       if (length(sigma.sq.p.inits) != p.det.re & length(sigma.sq.p.inits) != 1) {
         if (p.det.re == 1) {
-          stop(paste("error: initial values for sigma.sq.p must be of length ", p.det.re, 
+          stop(paste("error: initial values for sigma.sq.p must be of length ", p.det.re,
       	     sep = ""))
         } else {
-          stop(paste("error: initial values for sigma.sq.p must be of length ", p.det.re, 
+          stop(paste("error: initial values for sigma.sq.p must be of length ", p.det.re,
       	     " or 1", sep = ""))
         }
       }
@@ -797,7 +797,7 @@ msNMix <- function(abund.formula, det.formula, data, inits, priors,
     if ("kappa" %in% names(inits)) {
       kappa.inits <- inits[["kappa"]]
       if (length(kappa.inits) != n.sp & length(kappa.inits) != 1) {
-        stop(paste("error: initial values for kappa must be of length ", n.sp, " or 1", 
+        stop(paste("error: initial values for kappa must be of length ", n.sp, " or 1",
         	   sep = ""))
       }
       if (length(kappa.inits) != n.sp) {
@@ -841,9 +841,9 @@ msNMix <- function(abund.formula, det.formula, data, inits, priors,
     }
     beta.tuning <- tuning$beta
     if (length(beta.tuning) != 1 & length(beta.tuning) != p.abund * n.sp) {
-      stop(paste("error: beta tuning must be a single value or a vector of length ", 
+      stop(paste("error: beta tuning must be a single value or a vector of length ",
         	 p.abund * n.sp, sep = ''))
-    } 
+    }
     if (length(beta.tuning) == 1) {
       beta.tuning <- rep(beta.tuning, p.abund * n.sp)
     }
@@ -853,9 +853,9 @@ msNMix <- function(abund.formula, det.formula, data, inits, priors,
     }
     alpha.tuning <- tuning$alpha
     if (length(alpha.tuning) != 1 & length(alpha.tuning) != p.det * n.sp) {
-      stop(paste("error: alpha tuning must be a single value or a vector of length ", 
+      stop(paste("error: alpha tuning must be a single value or a vector of length ",
         	 p.det * n.sp, sep = ''))
-    } 
+    }
     if (length(alpha.tuning) == 1) {
       alpha.tuning <- rep(alpha.tuning, p.det * n.sp)
     }
@@ -867,10 +867,10 @@ msNMix <- function(abund.formula, det.formula, data, inits, priors,
       beta.star.tuning <- tuning$beta.star
       if (length(beta.star.tuning) != 1) {
         stop("error: beta.star tuning must be a single value")
-      } 
+      }
       beta.star.tuning <- rep(beta.star.tuning, n.abund.re * n.sp)
     } else {
-      beta.star.tuning <- NULL 
+      beta.star.tuning <- NULL
     }
     if (p.det.re > 0) {
       # alpha.star ---------------------------
@@ -880,10 +880,10 @@ msNMix <- function(abund.formula, det.formula, data, inits, priors,
       alpha.star.tuning <- tuning$alpha.star
       if (length(alpha.star.tuning) != 1) {
         stop("error: alpha.star tuning must be a single value")
-      } 
+      }
       alpha.star.tuning <- rep(alpha.star.tuning, n.det.re * n.sp)
     } else {
-      alpha.star.tuning <- NULL 
+      alpha.star.tuning <- NULL
     }
     # kappa ---------------------------
     if (family == 'NB') {
@@ -901,7 +901,7 @@ msNMix <- function(abund.formula, det.formula, data, inits, priors,
       kappa.tuning <- NULL
     }
   }
-  tuning.c <- log(c(beta.tuning, alpha.tuning, beta.star.tuning, 
+  tuning.c <- log(c(beta.tuning, alpha.tuning, beta.star.tuning,
 		    alpha.star.tuning, kappa.tuning))
 
   # Get max y values for N update -----------------------------------------
@@ -964,8 +964,8 @@ msNMix <- function(abund.formula, det.formula, data, inits, priors,
   storage.mode(n.report) <- "integer"
   chain.info <- c(curr.chain, n.chains)
   storage.mode(chain.info) <- "integer"
-  n.post.samples <- length(seq(from = n.burn + 1, 
-      			 to = n.samples, 
+  n.post.samples <- length(seq(from = n.burn + 1,
+      			 to = n.samples,
       			 by = as.integer(n.thin)))
   # samples.info order: burn-in, thinning rate, number of posterior samples
   samples.info <- c(n.burn, n.thin, n.post.samples)
@@ -1005,9 +1005,9 @@ msNMix <- function(abund.formula, det.formula, data, inits, priors,
       alpha.comm.inits <- rnorm(p.det, 0, 1)
       tau.sq.beta.inits <- runif(p.abund, 0.05, 1)
       tau.sq.alpha.inits <- runif(p.det, 0.05, 1)
-      beta.inits <- matrix(rnorm(n.sp * p.abund, beta.comm.inits, 
+      beta.inits <- matrix(rnorm(n.sp * p.abund, beta.comm.inits,
             		     sqrt(tau.sq.beta.inits)), n.sp, p.abund)
-      alpha.inits <- matrix(rnorm(n.sp * p.det, alpha.comm.inits, 
+      alpha.inits <- matrix(rnorm(n.sp * p.det, alpha.comm.inits,
             		      sqrt(tau.sq.alpha.inits)), n.sp, p.det)
       if (family == 'NB') {
         kappa.inits <- runif(n.sp, kappa.a, kappa.b)
@@ -1025,20 +1025,20 @@ msNMix <- function(abund.formula, det.formula, data, inits, priors,
     }
 
     storage.mode(chain.info) <- "integer"
-    out.tmp[[i]] <- .Call("msNMix", y, X, X.p, X.re, X.p.re, 
-        		  X.random, X.p.random, y.max, consts, 
-    	                  n.abund.re.long, n.det.re.long, beta.inits, 
-        		  alpha.inits, kappa.inits, N.inits, beta.comm.inits, 
-      	                  alpha.comm.inits, tau.sq.beta.inits, tau.sq.alpha.inits, 
-      		          sigma.sq.mu.inits, sigma.sq.p.inits, 
-    	                  beta.star.inits, alpha.star.inits, N.long.indx, 
-      		          beta.star.indx, beta.level.indx, alpha.star.indx, 
-      		          alpha.level.indx, mu.beta.comm, mu.alpha.comm, 
-      		          Sigma.beta.comm, Sigma.alpha.comm, kappa.a, 
-        		  kappa.b, tau.sq.beta.a, tau.sq.beta.b, tau.sq.alpha.a, 
-      	                  tau.sq.alpha.b, sigma.sq.mu.a, sigma.sq.mu.b, 
+    out.tmp[[i]] <- .Call("msNMix", y, X, X.p, X.re, X.p.re,
+        		  X.random, X.p.random, y.max, consts,
+    	                  n.abund.re.long, n.det.re.long, beta.inits,
+        		  alpha.inits, kappa.inits, N.inits, beta.comm.inits,
+      	                  alpha.comm.inits, tau.sq.beta.inits, tau.sq.alpha.inits,
+      		          sigma.sq.mu.inits, sigma.sq.p.inits,
+    	                  beta.star.inits, alpha.star.inits, N.long.indx,
+      		          beta.star.indx, beta.level.indx, alpha.star.indx,
+      		          alpha.level.indx, mu.beta.comm, mu.alpha.comm,
+      		          Sigma.beta.comm, Sigma.alpha.comm, kappa.a,
+        		  kappa.b, tau.sq.beta.a, tau.sq.beta.b, tau.sq.alpha.a,
+      	                  tau.sq.alpha.b, sigma.sq.mu.a, sigma.sq.mu.b,
       		          sigma.sq.p.a, sigma.sq.p.b,
-    	                  tuning.c, n.batch, batch.length, accept.rate, n.omp.threads, 
+    	                  tuning.c, n.batch, batch.length, accept.rate, n.omp.threads,
     	                  verbose, n.report, samples.info, chain.info, family.c, offset)
     chain.info[1] <- chain.info[1] + 1
   }
@@ -1046,39 +1046,39 @@ msNMix <- function(abund.formula, det.formula, data, inits, priors,
   out <- list()
   out$rhat <- list()
   if (n.chains > 1) {
-    # as.vector removes the "Upper CI" when there is only 1 variable. 
-    out$rhat$beta.comm <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a) 
-    					      mcmc(t(a$beta.comm.samples)))), 
-    			     autoburnin = FALSE)$psrf[, 2])
-    out$rhat$alpha.comm <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a) 
-    					      mcmc(t(a$alpha.comm.samples)))), 
-    			     autoburnin = FALSE)$psrf[, 2])
-    out$rhat$tau.sq.beta <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a) 
-    					      mcmc(t(a$tau.sq.beta.samples)))), 
-    			     autoburnin = FALSE)$psrf[, 2])
-    out$rhat$tau.sq.alpha <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a) 
-    					      mcmc(t(a$tau.sq.alpha.samples)))), 
-    			     autoburnin = FALSE)$psrf[, 2])
-    out$rhat$beta <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a) 
-    					         mcmc(t(a$beta.samples)))), 
-    			     autoburnin = FALSE)$psrf[, 2])
-    out$rhat$alpha <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a) 
-    					      mcmc(t(a$alpha.samples)))), 
-    			      autoburnin = FALSE)$psrf[, 2])
+    # as.vector removes the "Upper CI" when there is only 1 variable.
+    out$rhat$beta.comm <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a)
+    					      mcmc(t(a$beta.comm.samples)))),
+    			     autoburnin = FALSE, multivariate = FALSE)$psrf[, 2])
+    out$rhat$alpha.comm <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a)
+    					      mcmc(t(a$alpha.comm.samples)))),
+    			     autoburnin = FALSE, multivariate = FALSE)$psrf[, 2])
+    out$rhat$tau.sq.beta <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a)
+    					      mcmc(t(a$tau.sq.beta.samples)))),
+    			     autoburnin = FALSE, multivariate = FALSE)$psrf[, 2])
+    out$rhat$tau.sq.alpha <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a)
+    					      mcmc(t(a$tau.sq.alpha.samples)))),
+    			     autoburnin = FALSE, multivariate = FALSE)$psrf[, 2])
+    out$rhat$beta <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a)
+    					         mcmc(t(a$beta.samples)))),
+    			     autoburnin = FALSE, multivariate = FALSE)$psrf[, 2])
+    out$rhat$alpha <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a)
+    					      mcmc(t(a$alpha.samples)))),
+    			      autoburnin = FALSE, multivariate = FALSE)$psrf[, 2])
     if (family == 'NB') {
-      out$rhat$kappa <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a) 
-    					      mcmc(t(a$kappa.samples)))), 
-    			     autoburnin = FALSE)$psrf[, 2])
+      out$rhat$kappa <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a)
+    					      mcmc(t(a$kappa.samples)))),
+    			     autoburnin = FALSE, multivariate = FALSE)$psrf[, 2])
     }
     if (p.det.re > 0) {
-      out$rhat$sigma.sq.p <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a) 
-      					      mcmc(t(a$sigma.sq.p.samples)))), 
-      			     autoburnin = FALSE)$psrf[, 2])
+      out$rhat$sigma.sq.p <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a)
+      					      mcmc(t(a$sigma.sq.p.samples)))),
+      			     autoburnin = FALSE, multivariate = FALSE)$psrf[, 2])
     }
     if (p.abund.re > 0) {
-      out$rhat$sigma.sq.mu <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a) 
-      					      mcmc(t(a$sigma.sq.mu.samples)))), 
-      			     autoburnin = FALSE)$psrf[, 2])
+      out$rhat$sigma.sq.mu <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a)
+      					      mcmc(t(a$sigma.sq.mu.samples)))),
+      			     autoburnin = FALSE, multivariate = FALSE)$psrf[, 2])
     }
   } else {
     out$rhat$beta.comm <- rep(NA, p.abund)
@@ -1098,13 +1098,13 @@ msNMix <- function(abund.formula, det.formula, data, inits, priors,
   # Put everything into MCMC objects
   out$beta.comm.samples <- mcmc(do.call(rbind, lapply(out.tmp, function(a) t(a$beta.comm.samples))))
   colnames(out$beta.comm.samples) <- x.names
-  out$alpha.comm.samples <- mcmc(do.call(rbind, 
+  out$alpha.comm.samples <- mcmc(do.call(rbind,
     				lapply(out.tmp, function(a) t(a$alpha.comm.samples))))
   colnames(out$alpha.comm.samples) <- x.p.names
-  out$tau.sq.beta.samples <- mcmc(do.call(rbind, 
+  out$tau.sq.beta.samples <- mcmc(do.call(rbind,
     				lapply(out.tmp, function(a) t(a$tau.sq.beta.samples))))
   colnames(out$tau.sq.beta.samples) <- x.names
-  out$tau.sq.alpha.samples <- mcmc(do.call(rbind, 
+  out$tau.sq.alpha.samples <- mcmc(do.call(rbind,
     				lapply(out.tmp, function(a) t(a$tau.sq.alpha.samples))))
   colnames(out$tau.sq.alpha.samples) <- x.p.names
 
@@ -1119,12 +1119,12 @@ msNMix <- function(abund.formula, det.formula, data, inits, priors,
   colnames(out$alpha.samples) <- coef.names.det
   if (family == 'NB') {
     out$kappa.samples <- mcmc(do.call(rbind, lapply(out.tmp, function(a) t(a$kappa.samples))))
-    colnames(out$kappa.samples) <- paste('kappa', sp.names, sep = '-') 
+    colnames(out$kappa.samples) <- paste('kappa', sp.names, sep = '-')
   }
-  out$N.samples <- do.call(abind, lapply(out.tmp, function(a) array(a$N.samples, 
+  out$N.samples <- do.call(abind, lapply(out.tmp, function(a) array(a$N.samples,
     								dim = c(n.sp, J, n.post.samples))))
   out$N.samples <- aperm(out$N.samples, c(3, 1, 2))
-  out$mu.samples <- do.call(abind, lapply(out.tmp, function(a) array(a$mu.samples, 
+  out$mu.samples <- do.call(abind, lapply(out.tmp, function(a) array(a$mu.samples,
     								dim = c(n.sp, J, n.post.samples))))
   out$mu.samples <- aperm(out$mu.samples, c(3, 1, 2))
   if (p.det.re > 0) {
