@@ -1,9 +1,9 @@
-sfMsAbund <- function(formula, data, inits, priors,  
-                      tuning, cov.model = 'exponential', NNGP = TRUE, 
+sfMsAbund <- function(formula, data, inits, priors,
+                      tuning, cov.model = 'exponential', NNGP = TRUE,
                       n.neighbors = 15, search.type = 'cb', n.factors,
                       n.batch, batch.length, accept.rate = 0.43, family = 'Poisson',
-                      n.omp.threads = 1, verbose = TRUE, n.report = 100, 
-                      n.burn = round(.10 * n.batch * batch.length), 
+                      n.omp.threads = 1, verbose = TRUE, n.report = 100,
+                      n.burn = round(.10 * n.batch * batch.length),
 		      n.thin = 1, n.chains = 1, save.fitted = TRUE, ...){
 
   ptm <- proc.time()
@@ -12,9 +12,9 @@ sfMsAbund <- function(formula, data, inits, priors,
     stop("family must be either 'Poisson', 'NB', 'Gaussian', or 'zi-Gaussian'")
   }
   if (family %in% c('Gaussian', 'zi-Gaussian')) {
-    sfMsAbundGaussian(formula, data, inits, priors, tuning, cov.model, 
+    sfMsAbundGaussian(formula, data, inits, priors, tuning, cov.model,
 		      NNGP, n.neighbors, search.type, n.factors, n.batch,
-		      batch.length, accept.rate, family, n.omp.threads, 
+		      batch.length, accept.rate, family, n.omp.threads,
 		      verbose, n.report, n.burn, n.thin, n.chains, save.fitted)
   } else {
 
@@ -25,14 +25,14 @@ sfMsAbund <- function(formula, data, inits, priors,
     rigamma <- function(n, a, b){
       1/rgamma(n = n, shape = a, rate = b)
     }
- 
+
     # Make it look nice
     if (verbose) {
       cat("----------------------------------------\n");
       cat("\tPreparing to run the model\n");
       cat("----------------------------------------\n");
     }
-    # Check for unused arguments ------------------------------------------	
+    # Check for unused arguments ------------------------------------------
     formal.args <- names(formals(sys.function(sys.parent())))
     elip.args <- names(list(...))
     for(i in elip.args){
@@ -40,14 +40,14 @@ sfMsAbund <- function(formula, data, inits, priors,
             warning("'",i, "' is not an argument")
     }
     # Call ----------------------------------------------------------------
-    # Returns a call in which all of the specified arguments are 
-    # specified by their full names. 
+    # Returns a call in which all of the specified arguments are
+    # specified by their full names.
     cl <- match.call()
 
     # Some initial checks -------------------------------------------------
     # Only implemented for NNGP
     if (!NNGP) {
-      stop("error: sfMsAbund is currently only implemented for NNGPs, not full Gaussian Processes. Please set NNGP = TRUE.") 
+      stop("error: sfMsAbund is currently only implemented for NNGPs, not full Gaussian Processes. Please set NNGP = TRUE.")
     }
     if (missing(data)) {
       stop("error: data must be specified")
@@ -72,17 +72,17 @@ sfMsAbund <- function(formula, data, inits, priors,
     if ('offset' %in% names(data)) {
       offset <- data$offset
       if (length(offset) == 1) {
-        offset <- matrix(offset, ncol(y), dim(y)[3]) 
+        offset <- matrix(offset, ncol(y), dim(y)[3])
       } else if (length(dim(offset)) == 1) { # Value for each site
         if (length(offset) != ncol(y)) {
-          stop(paste0("offset must be a single value, vector of length ", ncol(y), " or a matrix with ", 
-                     ncol(y), " rows and ", dim(y)[3], " columns."))	
+          stop(paste0("offset must be a single value, vector of length ", ncol(y), " or a matrix with ",
+                     ncol(y), " rows and ", dim(y)[3], " columns."))
         }
         offset <- matrix(offset, ncol(y), dim(y)[3])
       } else if (length(dim(offset)) == 2) { # Value for each site/obs
         if (nrow(offset) != ncol(y) | ncol(offset) != dim(y)[3]) {
-          stop(paste0("offset must be a single value, vector of length ", ncol(y), " or a matrix with ", 
-                      ncol(y), " rows and ", dim(y)[3], " columns."))	
+          stop(paste0("offset must be a single value, vector of length ", ncol(y), " or a matrix with ",
+                      ncol(y), " rows and ", dim(y)[3], " columns."))
 
         }
       }
@@ -127,14 +127,14 @@ sfMsAbund <- function(formula, data, inits, priors,
     }
 
     if (family == 'NB' & verbose) {
-      message('**NOTE**: spatial negative binomial models can be difficult to\nestimate as they contain two forms of overdispersion. If experiencing\nvery poor mixing/convergence of MCMC chains (particularly kappa and phi),\nconsider using a spatial Poisson model or more informative\npriors on kappa or phi.\n') 
+      message('**NOTE**: spatial negative binomial models can be difficult to\nestimate as they contain two forms of overdispersion. If experiencing\nvery poor mixing/convergence of MCMC chains (particularly kappa and phi),\nconsider using a spatial Poisson model or more informative\npriors on kappa or phi.\n')
     }
 
     # Neighbors and Ordering ----------------------------------------------
     if (NNGP) {
-      u.search.type <- 2 
-      ## Order by x column. Could potentially allow this to be user defined. 
-      ord <- order(coords[,1]) 
+      u.search.type <- 2
+      ## Order by x column. Could potentially allow this to be user defined.
+      ord <- order(coords[,1])
       # Reorder everything to align with NN ordering
       y <- y[, ord, , drop = FALSE]
       offset <- offset[ord, , drop = FALSE]
@@ -152,7 +152,7 @@ sfMsAbund <- function(formula, data, inits, priors,
     y.mat <- y
     offset.mat <- offset
 
-    # First subset covariates to only use those that are included in the analysis. 
+    # First subset covariates to only use those that are included in the analysis.
     # Get occurrence covariates in proper format
     # Subset covariates to only use those that are included in the analysis
     data$covs <- data$covs[names(data$covs) %in% all.vars(formula)]
@@ -168,14 +168,14 @@ sfMsAbund <- function(formula, data, inits, priors,
     }
 
     # Check whether random effects are sent in as numeric, and
-    # return error if they are. 
+    # return error if they are.
     # Abundance -------------------------
     if (!is.null(findbars(formula))) {
       abund.re.names <- unique(unlist(sapply(findbars(formula), all.vars)))
       for (i in 1:length(abund.re.names)) {
         if (is(data$covs[, abund.re.names[i]], 'factor')) {
           stop(paste("error: random effect variable ", abund.re.names[i], " specified as a factor. Random effect variables must be specified as numeric.", sep = ''))
-        } 
+        }
         if (is(data$covs[, abund.re.names[i]], 'character')) {
           stop(paste("error: random effect variable ", abund.re.names[i], " specified as character. Random effect variables must be specified as numeric.", sep = ''))
         }
@@ -190,9 +190,9 @@ sfMsAbund <- function(formula, data, inits, priors,
     }
     # covs ------------------------
     for (i in 1:ncol(data$covs)) {
-      # Note that this assumes the same detection history for each species.  
+      # Note that this assumes the same detection history for each species.
       if (sum(is.na(data$covs[, i])) > sum(is.na(y.mat[1, , ]))) {
-        stop("error: some elements in covs have missing values where there is an observed data value in y. Please either replace the NA values in covs with non-missing values (e.g., mean imputation) or set the corresponding values in y to NA where the covariate is missing.") 
+        stop("error: some elements in covs have missing values where there is an observed data value in y. Please either replace the NA values in covs with non-missing values (e.g., mean imputation) or set the corresponding values in y to NA where the covariate is missing.")
       }
     }
     # Misalignment between y and covs
@@ -240,11 +240,11 @@ sfMsAbund <- function(formula, data, inits, priors,
     x.re.names <- x.random.names
 
     # Extract data from inputs --------------------------------------------
-    # Number of species 
+    # Number of species
     n.sp <- dim(y)[1]
     # Number of latent factors
     q <- n.factors
-    # Number of abundance parameters 
+    # Number of abundance parameters
     p.abund <- ncol(X)
     # Number of abundance random effect parameters
     p.abund.re <- ncol(X.re)
@@ -254,25 +254,25 @@ sfMsAbund <- function(formula, data, inits, priors,
     # Number of sites
     J <- nrow(coords)
     # Number of replicate surveys
-    # Note this assumes equivalent detection histories for all species. 
-    # May want to change this at some point. 
+    # Note this assumes equivalent detection histories for all species.
+    # May want to change this at some point.
     n.rep <- apply(y.mat[1, , , drop = FALSE], 2, function(a) sum(!is.na(a)))
     K.max <- dim(y.mat)[3]
     # Because I like K better than n.rep
     K <- n.rep
 
     # Get indices to map N to y -------------------------------------------
-    site.indx <- rep(1:J, dim(y.mat)[3]) 
+    site.indx <- rep(1:J, dim(y.mat)[3])
     site.indx <- site.indx[!is.na(c(y.mat[1, , ]))]
     # Subtract 1 for indices in C
     site.indx <- site.indx - 1
     # y is stored in the following order: species, site, visit
     y <- c(y)
     offset <- c(offset)
-    # Assumes the missing data are constant across species, which seems likely, 
-    # but may eventually need some updating. 
+    # Assumes the missing data are constant across species, which seems likely,
+    # but may eventually need some updating.
     names.long <- which(!is.na(c(y.mat[1, , ])))
-    # Only need to check this when there are observation level covariates. 
+    # Only need to check this when there are observation level covariates.
     if (nrow(X) == length(y) / n.sp) {
       X <- X[!is.na(c(y.mat[1, , ])), , drop = FALSE]
     }
@@ -307,10 +307,10 @@ sfMsAbund <- function(formula, data, inits, priors,
         message("Beta parameters will be estimated independently\n")
         ind.betas <- TRUE
       } else if (priors$independent.betas == FALSE) {
-        ind.betas <- FALSE 
+        ind.betas <- FALSE
       }
     } else {
-      ind.betas <- FALSE 
+      ind.betas <- FALSE
     }
     # beta.comm -----------------------
     if ("beta.comm.normal" %in% names(priors)) {
@@ -350,7 +350,7 @@ sfMsAbund <- function(formula, data, inits, priors,
       }
       mu.beta.comm <- rep(0, p.abund)
       sigma.beta.comm <- rep(100, p.abund)
-      Sigma.beta.comm <- diag(p.abund) * 100 
+      Sigma.beta.comm <- diag(p.abund) * 100
     }
 
     # tau.sq.beta -----------------------
@@ -362,19 +362,19 @@ sfMsAbund <- function(formula, data, inits, priors,
       tau.sq.beta.b <- priors$tau.sq.beta.ig[[2]]
       if (length(tau.sq.beta.a) != p.abund & length(tau.sq.beta.a) != 1) {
         if (p.abund == 1) {
-          stop(paste("error: tau.sq.beta.ig[[1]] must be a vector of length ", 
+          stop(paste("error: tau.sq.beta.ig[[1]] must be a vector of length ",
         	   p.abund, " with elements corresponding to tau.sq.betas' shape", sep = ""))
         } else {
-          stop(paste("error: tau.sq.beta.ig[[1]] must be a vector of length ", 
+          stop(paste("error: tau.sq.beta.ig[[1]] must be a vector of length ",
         	   p.abund, " or 1 with elements corresponding to tau.sq.betas' shape", sep = ""))
         }
       }
       if (length(tau.sq.beta.b) != p.abund & length(tau.sq.beta.b) != 1) {
         if (p.abund == 1) {
-          stop(paste("error: tau.sq.beta.ig[[2]] must be a vector of length ", 
+          stop(paste("error: tau.sq.beta.ig[[2]] must be a vector of length ",
         	   p.abund, " with elements corresponding to tau.sq.betas' scale", sep = ""))
         } else {
-          stop(paste("error: tau.sq.beta.ig[[2]] must be a vector of length ", 
+          stop(paste("error: tau.sq.beta.ig[[2]] must be a vector of length ",
         	   p.abund, " or 1 with elements corresponding to tau.sq.betas' scale", sep = ""))
         }
       }
@@ -385,7 +385,7 @@ sfMsAbund <- function(formula, data, inits, priors,
         tau.sq.beta.b <- rep(tau.sq.beta.b, p.abund)
       }
     } else {
-      if (verbose & !ind.betas) {	    
+      if (verbose & !ind.betas) {
         message("No prior specified for tau.sq.beta.ig.\nSetting prior shape to 0.1 and prior scale to 0.1\n")
       }
       tau.sq.beta.a <- rep(0.1, p.abund)
@@ -401,19 +401,19 @@ sfMsAbund <- function(formula, data, inits, priors,
         sigma.sq.mu.b <- priors$sigma.sq.mu.ig[[2]]
         if (length(sigma.sq.mu.a) != p.abund.re & length(sigma.sq.mu.a) != 1) {
           if (p.abund.re == 1) {
-          stop(paste("error: sigma.sq.mu.ig[[1]] must be a vector of length ", 
+          stop(paste("error: sigma.sq.mu.ig[[1]] must be a vector of length ",
           	   p.abund.re, " with elements corresponding to sigma.sq.mus' shape", sep = ""))
           } else {
-          stop(paste("error: sigma.sq.mu.ig[[1]] must be a vector of length ", 
+          stop(paste("error: sigma.sq.mu.ig[[1]] must be a vector of length ",
           	   p.abund.re, " or 1 with elements corresponding to sigma.sq.mus' shape", sep = ""))
           }
         }
         if (length(sigma.sq.mu.b) != p.abund.re & length(sigma.sq.mu.b) != 1) {
           if (p.abund.re == 1) {
-            stop(paste("error: sigma.sq.mu.ig[[2]] must be a vector of length ", 
+            stop(paste("error: sigma.sq.mu.ig[[2]] must be a vector of length ",
           	   p.abund.re, " with elements corresponding to sigma.sq.mus' scale", sep = ""))
           } else {
-            stop(paste("error: sigma.sq.mu.ig[[2]] must be a vector of length ", 
+            stop(paste("error: sigma.sq.mu.ig[[2]] must be a vector of length ",
           	   p.abund.re, " or 1with elements corresponding to sigma.sq.mus' scale", sep = ""))
           }
         }
@@ -424,7 +424,7 @@ sfMsAbund <- function(formula, data, inits, priors,
           sigma.sq.mu.b <- rep(sigma.sq.mu.b, p.abund.re)
         }
     }   else {
-        if (verbose) {	    
+        if (verbose) {
           message("No prior specified for sigma.sq.mu.ig.\nSetting prior shape to 0.1 and prior scale to 0.1\n")
         }
         sigma.sq.mu.a <- rep(0.1, p.abund.re)
@@ -443,11 +443,11 @@ sfMsAbund <- function(formula, data, inits, priors,
         kappa.a <- priors$kappa.unif[[1]]
         kappa.b <- priors$kappa.unif[[2]]
         if (length(kappa.a) != n.sp & length(kappa.a) != 1) {
-          stop(paste("error: kappa.unif[[1]] must be a vector of length ", 
+          stop(paste("error: kappa.unif[[1]] must be a vector of length ",
           	   n.sp, " or 1 with elements corresponding to kappas' lower bound for each species", sep = ""))
         }
         if (length(kappa.b) != n.sp & length(kappa.b) != 1) {
-          stop(paste("error: kappa.unif[[2]] must be a vector of length ", 
+          stop(paste("error: kappa.unif[[2]] must be a vector of length ",
           	   n.sp, " or 1 with elements corresponding to kappas' upper bound for each species", sep = ""))
         }
         if (length(kappa.a) != n.sp) {
@@ -476,11 +476,11 @@ sfMsAbund <- function(formula, data, inits, priors,
       phi.a <- priors$phi.unif[[1]]
       phi.b <- priors$phi.unif[[2]]
       if (length(phi.a) != q & length(phi.a) != 1) {
-        stop(paste("error: phi.unif[[1]] must be a vector of length ", 
+        stop(paste("error: phi.unif[[1]] must be a vector of length ",
         	   q, " or 1 with elements corresponding to phis' lower bound for each latent factor", sep = ""))
       }
       if (length(phi.b) != q & length(phi.b) != 1) {
-        stop(paste("error: phi.unif[[2]] must be a vector of length ", 
+        stop(paste("error: phi.unif[[2]] must be a vector of length ",
         	   q, " or 1 with elements corresponding to phis' upper bound for each latent factor", sep = ""))
       }
       if (length(phi.a) != q) {
@@ -508,11 +508,11 @@ sfMsAbund <- function(formula, data, inits, priors,
         stop("error: nu.unif must be a list of length 2")
       }
       if (length(nu.a) != q & length(nu.a) != 1) {
-        stop(paste("error: nu.unif[[1]] must be a vector of length ", 
+        stop(paste("error: nu.unif[[1]] must be a vector of length ",
         	   q, " or 1 with elements corresponding to nus' lower bound for each latent factor", sep = ""))
       }
       if (length(nu.b) != q & length(nu.b) != 1) {
-        stop(paste("error: nu.unif[[2]] must be a vector of length ", 
+        stop(paste("error: nu.unif[[2]] must be a vector of length ",
         	   q, " or 1 with elements corresponding to nus' upper bound for each latent factor", sep = ""))
       }
       if (length(nu.a) != q) {
@@ -536,10 +536,10 @@ sfMsAbund <- function(formula, data, inits, priors,
       beta.comm.inits <- inits[["beta.comm"]]
       if (length(beta.comm.inits) != p.abund & length(beta.comm.inits) != 1) {
         if (p.abund == 1) {
-          stop(paste("error: initial values for beta.comm must be of length ", p.abund, 
+          stop(paste("error: initial values for beta.comm must be of length ", p.abund,
         	   sep = ""))
         } else {
-          stop(paste("error: initial values for beta.comm must be of length ", p.abund, 
+          stop(paste("error: initial values for beta.comm must be of length ", p.abund,
         	   , " or 1", sep = ""))
         }
       }
@@ -557,10 +557,10 @@ sfMsAbund <- function(formula, data, inits, priors,
       tau.sq.beta.inits <- inits[["tau.sq.beta"]]
       if (length(tau.sq.beta.inits) != p.abund & length(tau.sq.beta.inits) != 1) {
         if (p.abund == 1) {
-          stop(paste("error: initial values for tau.sq.beta must be of length ", p.abund, 
+          stop(paste("error: initial values for tau.sq.beta must be of length ", p.abund,
         	   sep = ""))
         } else {
-          stop(paste("error: initial values for tau.sq.beta must be of length ", p.abund, 
+          stop(paste("error: initial values for tau.sq.beta must be of length ", p.abund,
         	   " or 1", sep = ""))
         }
       }
@@ -578,12 +578,12 @@ sfMsAbund <- function(formula, data, inits, priors,
       beta.inits <- inits[["beta"]]
       if (is.matrix(beta.inits)) {
         if (ncol(beta.inits) != p.abund | nrow(beta.inits) != n.sp) {
-          stop(paste("error: initial values for beta must be a matrix with dimensions ", 
+          stop(paste("error: initial values for beta must be a matrix with dimensions ",
           	   n.sp, "x", p.abund, " or a single numeric value", sep = ""))
         }
       }
       if (!is.matrix(beta.inits) & length(beta.inits) != 1) {
-        stop(paste("error: initial values for beta must be a matrix with dimensions ", 
+        stop(paste("error: initial values for beta must be a matrix with dimensions ",
         	   n.sp, " x ", p.abund, " or a single numeric value", sep = ""))
       }
       if (length(beta.inits) == 1) {
@@ -601,15 +601,15 @@ sfMsAbund <- function(formula, data, inits, priors,
         sigma.sq.mu.inits <- inits[["sigma.sq.mu"]]
         if (length(sigma.sq.mu.inits) != p.abund.re & length(sigma.sq.mu.inits) != 1) {
           if (p.abund.re == 1) {
-            stop(paste("error: initial values for sigma.sq.mu must be of length ", p.abund.re, 
+            stop(paste("error: initial values for sigma.sq.mu must be of length ", p.abund.re,
         	     sep = ""))
           } else {
-            stop(paste("error: initial values for sigma.sq.mu must be of length ", p.abund.re, 
+            stop(paste("error: initial values for sigma.sq.mu must be of length ", p.abund.re,
         	     " or 1", sep = ""))
           }
         }
         if (length(sigma.sq.mu.inits) != p.abund.re) {
-          sigma.sq.mu.inits <- rep(sigma.sq.mu.inits, p.abund.re)  
+          sigma.sq.mu.inits <- rep(sigma.sq.mu.inits, p.abund.re)
         }
       } else {
         sigma.sq.mu.inits <- runif(p.abund.re, 0.05, 1)
@@ -619,7 +619,7 @@ sfMsAbund <- function(formula, data, inits, priors,
       }
       beta.star.indx <- rep(0:(p.abund.re - 1), n.abund.re.long)
       beta.star.inits <- rnorm(n.abund.re, sqrt(sigma.sq.mu.inits[beta.star.indx + 1]))
-      # Starting values for all species 
+      # Starting values for all species
       beta.star.inits <- rep(beta.star.inits, n.sp)
     } else {
       sigma.sq.mu.inits <- 0
@@ -632,7 +632,7 @@ sfMsAbund <- function(formula, data, inits, priors,
       if ("kappa" %in% names(inits)) {
         kappa.inits <- inits[["kappa"]]
         if (length(kappa.inits) != n.sp & length(kappa.inits) != 1) {
-          stop(paste("error: initial values for kappa must be of length ", n.sp, " or 1", 
+          stop(paste("error: initial values for kappa must be of length ", n.sp, " or 1",
           	   sep = ""))
         }
         if (length(kappa.inits) != n.sp) {
@@ -652,7 +652,7 @@ sfMsAbund <- function(formula, data, inits, priors,
     if ("phi" %in% names(inits)) {
       phi.inits <- inits[["phi"]]
       if (length(phi.inits) != q & length(phi.inits) != 1) {
-        stop(paste("error: initial values for phi must be of length ", q, " or 1", 
+        stop(paste("error: initial values for phi must be of length ", q, " or 1",
         	   sep = ""))
       }
       if (length(phi.inits) != q) {
@@ -685,8 +685,8 @@ sfMsAbund <- function(formula, data, inits, priors,
       }
     }
     # lambda ----------------------------
-    # ORDER: an n.sp x q matrix sent in as a column-major vector, which is ordered by 
-    #        factor, then species within factor. 
+    # ORDER: an n.sp x q matrix sent in as a column-major vector, which is ordered by
+    #        factor, then species within factor.
     if ("lambda" %in% names(inits)) {
       lambda.inits <- inits[["lambda"]]
       if (!is.matrix(lambda.inits)) {
@@ -711,7 +711,7 @@ sfMsAbund <- function(formula, data, inits, priors,
         message("lambda is not specified in initial values.\nSetting initial values of the lower triangle to 0\n")
       }
       # lambda.inits are organized by factor, then by species. This is necessary for working
-      # with dgemv.  
+      # with dgemv.
       lambda.inits <- c(lambda.inits)
     }
     # w -----------------------------
@@ -750,7 +750,7 @@ sfMsAbund <- function(formula, data, inits, priors,
     # Order must match util.cpp spCor.
     cov.model.names <- c("exponential", "spherical", "matern", "gaussian")
     if(! cov.model %in% cov.model.names){
-      stop("error: specified cov.model '",cov.model,"' is not a valid option; choose from ", 
+      stop("error: specified cov.model '",cov.model,"' is not a valid option; choose from ",
            paste(cov.model.names, collapse=", ", sep="") ,".")}
     # Obo for cov model lookup on c side
     cov.model.indx <- which(cov.model == cov.model.names) - 1
@@ -778,9 +778,9 @@ sfMsAbund <- function(formula, data, inits, priors,
       }
       beta.tuning <- tuning$beta
       if (length(beta.tuning) != 1 & length(beta.tuning) != p.abund * n.sp) {
-        stop(paste("error: beta tuning must be a single value or a vector of length ", 
+        stop(paste("error: beta tuning must be a single value or a vector of length ",
           	 p.abund * n.sp, sep = ''))
-      } 
+      }
       if (length(beta.tuning) == 1) {
         beta.tuning <- rep(beta.tuning, p.abund * n.sp)
       }
@@ -792,10 +792,10 @@ sfMsAbund <- function(formula, data, inits, priors,
         beta.star.tuning <- tuning$beta.star
         if (length(beta.star.tuning) != 1) {
           stop("error: beta.star tuning must be a single value")
-        } 
+        }
         beta.star.tuning <- rep(beta.star.tuning, n.abund.re * n.sp)
       } else {
-        beta.star.tuning <- NULL 
+        beta.star.tuning <- NULL
       }
       # kappa ---------------------------
       if (family == 'NB') {
@@ -844,9 +844,9 @@ sfMsAbund <- function(formula, data, inits, priors,
       }
       w.tuning <- tuning$w
       if (length(w.tuning) != 1 & length(w.tuning) != J * q) {
-        stop(paste("error: w tuning must be a single value or a vector of length ", 
+        stop(paste("error: w tuning must be a single value or a vector of length ",
           	 J * q, sep = ''))
-      } 
+      }
       if (length(w.tuning) == 1) {
         w.tuning <- rep(w.tuning, J * q)
       }
@@ -856,9 +856,9 @@ sfMsAbund <- function(formula, data, inits, priors,
       }
       lambda.tuning <- tuning$lambda
       if (length(lambda.tuning) != 1 & length(lambda.tuning) != n.sp * q) {
-        stop(paste("error: lambda tuning must be a single value or a vector of length ", 
+        stop(paste("error: lambda tuning must be a single value or a vector of length ",
           	 n.sp * q, sep = ''))
-      } 
+      }
       if (length(lambda.tuning) == 1) {
         lambda.tuning <- rep(lambda.tuning, n.sp * q)
       }
@@ -879,7 +879,7 @@ sfMsAbund <- function(formula, data, inits, priors,
 
     curr.chain <- 1
     if (!NNGP)  {
-      stop("error: sfMsAbund is currently only implemented for NNGPs, not full Gaussian Processes. Please set NNGP = TRUE.") 
+      stop("error: sfMsAbund is currently only implemented for NNGPs, not full Gaussian Processes. Please set NNGP = TRUE.")
 
     } else {
       # Nearest Neighbor Search ---------------------------------------------
@@ -890,32 +890,32 @@ sfMsAbund <- function(formula, data, inits, priors,
       }
 
       search.type.names <- c("brute", "cb")
-      
+
       if(!search.type %in% search.type.names){
         stop("error: specified search.type '",search.type,
-             "' is not a valid option; choose from ", 
+             "' is not a valid option; choose from ",
              paste(search.type.names, collapse=", ", sep="") ,".")
       }
-      
+
       ## Indexes
       if(search.type == "brute"){
         indx <- mkNNIndx(coords, n.neighbors, n.omp.threads)
       } else{
         indx <- mkNNIndxCB(coords, n.neighbors, n.omp.threads)
       }
-      
+
       nn.indx <- indx$nnIndx
       nn.indx.lu <- indx$nnIndxLU
       nn.indx.run.time <- indx$run.time
-      
+
       if(verbose){
         cat("----------------------------------------\n");
         cat("Building the neighbors of neighbors list\n");
         cat("----------------------------------------\n");
       }
-      
+
       indx <- mkUIndx(J, n.neighbors, nn.indx, nn.indx.lu, u.search.type)
-      
+
       u.indx <- indx$u.indx
       u.indx.lu <- indx$u.indx.lu
       ui.indx <- indx$ui.indx
@@ -963,8 +963,8 @@ sfMsAbund <- function(formula, data, inits, priors,
       storage.mode(cov.model.indx) <- "integer"
       chain.info <- c(curr.chain, n.chains)
       storage.mode(chain.info) <- "integer"
-      n.post.samples <- length(seq(from = n.burn + 1, 
-          			 to = n.samples, 
+      n.post.samples <- length(seq(from = n.burn + 1,
+          			 to = n.samples,
           			 by = as.integer(n.thin)))
       # samples.info order: burn-in, thinning rate, number of posterior samples
       samples.info <- c(n.burn, n.thin, n.post.samples)
@@ -993,7 +993,7 @@ sfMsAbund <- function(formula, data, inits, priors,
             beta.comm.inits <- rnorm(p.abund, 0, 1)
             tau.sq.beta.inits <- runif(p.abund, 0.05, 1)
 	  }
-          beta.inits <- matrix(rnorm(n.sp * p.abund, beta.comm.inits, 
+          beta.inits <- matrix(rnorm(n.sp * p.abund, beta.comm.inits,
                 		     sqrt(tau.sq.beta.inits)), n.sp, p.abund)
           if (family == 'NB') {
             kappa.inits <- runif(n.sp, kappa.a, kappa.b)
@@ -1014,19 +1014,19 @@ sfMsAbund <- function(formula, data, inits, priors,
         }
 
         storage.mode(chain.info) <- "integer"
-        out.tmp[[i]] <- .Call("sfMsAbundNNGP", y, X, coords, X.re, X.random, 
-        		      consts, n.abund.re.long, 
+        out.tmp[[i]] <- .Call("sfMsAbundNNGP", y, X, coords, X.re, X.random,
+        		      consts, n.abund.re.long,
           	              n.neighbors, nn.indx, nn.indx.lu, u.indx, u.indx.lu, ui.indx,
-          		      beta.inits, kappa.inits, beta.comm.inits, 
-          	              tau.sq.beta.inits, 
+          		      beta.inits, kappa.inits, beta.comm.inits,
+          	              tau.sq.beta.inits,
           		      phi.inits, lambda.inits, nu.inits, w.inits,
-          		      sigma.sq.mu.inits, beta.star.inits,site.indx, 
-          		      beta.star.indx, beta.level.indx,  
-          		      mu.beta.comm, Sigma.beta.comm, kappa.a, 
-            		      kappa.b, tau.sq.beta.a, tau.sq.beta.b,  
-          	              phi.a, phi.b, nu.a, nu.b, 
-          		      sigma.sq.mu.a, sigma.sq.mu.b, tuning.c, cov.model.indx, 
-          		      n.batch, batch.length, accept.rate, n.omp.threads, 
+          		      sigma.sq.mu.inits, beta.star.inits,site.indx,
+          		      beta.star.indx, beta.level.indx,
+          		      mu.beta.comm, Sigma.beta.comm, kappa.a,
+            		      kappa.b, tau.sq.beta.a, tau.sq.beta.b,
+          	              phi.a, phi.b, nu.a, nu.b,
+          		      sigma.sq.mu.a, sigma.sq.mu.b, tuning.c, cov.model.indx,
+          		      n.batch, batch.length, accept.rate, n.omp.threads,
         	              verbose, n.report, samples.info, chain.info, family.c, offset)
         chain.info[1] <- chain.info[1] + 1
       }
@@ -1034,37 +1034,37 @@ sfMsAbund <- function(formula, data, inits, priors,
       out <- list()
       out$rhat <- list()
       if (n.chains > 1) {
-        # as.vector removes the "Upper CI" when there is only 1 variable. 
+        # as.vector removes the "Upper CI" when there is only 1 variable.
         if (!ind.betas) {
-        out$rhat$beta.comm <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a) 
-        					      mcmc(t(a$beta.comm.samples)))), 
-        			     autoburnin = FALSE)$psrf[, 2])
-        out$rhat$tau.sq.beta <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a) 
-        					      mcmc(t(a$tau.sq.beta.samples)))), 
-        			     autoburnin = FALSE)$psrf[, 2])
+        out$rhat$beta.comm <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a)
+        					      mcmc(t(a$beta.comm.samples)))),
+        			     autoburnin = FALSE, multivariate = FALSE)$psrf[, 2])
+        out$rhat$tau.sq.beta <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a)
+        					      mcmc(t(a$tau.sq.beta.samples)))),
+        			     autoburnin = FALSE, multivariate = FALSE)$psrf[, 2])
 	} else {
           out$rhat$beta.comm <- rep(NA, p.abund)
 	  out$rhat$tau.sq.beta <- rep(NA, p.abund)
 	}
-        out$rhat$beta <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a) 
-        					         mcmc(t(a$beta.samples)))), 
-        			     autoburnin = FALSE)$psrf[, 2])
+        out$rhat$beta <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a)
+        					         mcmc(t(a$beta.samples)))),
+        			     autoburnin = FALSE, multivariate = FALSE)$psrf[, 2])
         if (family == 'NB') {
-          out$rhat$kappa <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a) 
-        					      mcmc(t(a$kappa.samples)))), 
-        			     autoburnin = FALSE)$psrf[, 2])
+          out$rhat$kappa <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a)
+        					      mcmc(t(a$kappa.samples)))),
+        			     autoburnin = FALSE, multivariate = FALSE)$psrf[, 2])
         }
-        out$rhat$theta <- gelman.diag(mcmc.list(lapply(out.tmp, function(a) 
-        					      mcmc(t(a$theta.samples)))), 
-        			      autoburnin = FALSE)$psrf[, 2]
+        out$rhat$theta <- gelman.diag(mcmc.list(lapply(out.tmp, function(a)
+        					      mcmc(t(a$theta.samples)))),
+        			      autoburnin = FALSE, multivariate = FALSE)$psrf[, 2]
         lambda.mat <- matrix(lambda.inits, n.sp, q)
-        out$rhat$lambda.lower.tri <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a) 
-          					       mcmc(t(a$lambda.samples[c(lower.tri(lambda.mat)), ])))), 
-          					       autoburnin = FALSE)$psrf[, 2])
+        out$rhat$lambda.lower.tri <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a)
+          					       mcmc(t(a$lambda.samples[c(lower.tri(lambda.mat)), ])))),
+          					       autoburnin = FALSE, multivariate = FALSE)$psrf[, 2])
         if (p.abund.re > 0) {
-          out$rhat$sigma.sq.mu <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a) 
-          					      mcmc(t(a$sigma.sq.mu.samples)))), 
-          			     autoburnin = FALSE)$psrf[, 2])
+          out$rhat$sigma.sq.mu <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a)
+          					      mcmc(t(a$sigma.sq.mu.samples)))),
+          			     autoburnin = FALSE, multivariate = FALSE)$psrf[, 2])
         }
       } else {
         out$rhat$beta.comm <- rep(NA, p.abund)
@@ -1079,7 +1079,7 @@ sfMsAbund <- function(formula, data, inits, priors,
       # Put everything into MCMC objects
       out$beta.comm.samples <- mcmc(do.call(rbind, lapply(out.tmp, function(a) t(a$beta.comm.samples))))
       colnames(out$beta.comm.samples) <- x.names
-      out$tau.sq.beta.samples <- mcmc(do.call(rbind, 
+      out$tau.sq.beta.samples <- mcmc(do.call(rbind,
         				lapply(out.tmp, function(a) t(a$tau.sq.beta.samples))))
       colnames(out$tau.sq.beta.samples) <- x.names
 
@@ -1091,7 +1091,7 @@ sfMsAbund <- function(formula, data, inits, priors,
       colnames(out$beta.samples) <- coef.names
       if (family == 'NB') {
         out$kappa.samples <- mcmc(do.call(rbind, lapply(out.tmp, function(a) t(a$kappa.samples))))
-        colnames(out$kappa.samples) <- paste('kappa', sp.names, sep = '-') 
+        colnames(out$kappa.samples) <- paste('kappa', sp.names, sep = '-')
       }
       loadings.names <- paste(rep(sp.names, times = n.factors), rep(1:n.factors, each = n.sp), sep = '-')
       out$lambda.samples <- mcmc(do.call(rbind, lapply(out.tmp, function(a) t(a$lambda.samples))))
@@ -1101,11 +1101,11 @@ sfMsAbund <- function(formula, data, inits, priors,
         theta.names <- paste(rep(c('phi'), each = q), 1:q, sep = '-')
       } else {
         theta.names <- paste(rep(c('phi', 'nu'), each = q), 1:q, sep = '-')
-      } 
+      }
       colnames(out$theta.samples) <- theta.names
       y.non.miss.indx <- which(!is.na(y.mat), arr.ind = TRUE)
       if (save.fitted) {
-        out$y.rep.samples <- do.call(abind, lapply(out.tmp, function(a) array(a$y.rep.samples, 
+        out$y.rep.samples <- do.call(abind, lapply(out.tmp, function(a) array(a$y.rep.samples,
           								dim = c(n.sp * n.obs, n.post.samples))))
         tmp <- array(NA, dim = c(n.post.samples * n.chains, n.sp, J, K.max))
         for (j in 1:(n.obs * n.sp)) {
@@ -1113,7 +1113,7 @@ sfMsAbund <- function(formula, data, inits, priors,
           tmp[, curr.indx[1], curr.indx[2], curr.indx[3]] <- out$y.rep.samples[j, ]
         }
         out$y.rep.samples <- tmp[, , order(ord), , drop = FALSE]
-        out$mu.samples <- do.call(abind, lapply(out.tmp, function(a) array(a$mu.samples, 
+        out$mu.samples <- do.call(abind, lapply(out.tmp, function(a) array(a$mu.samples,
           								dim = c(n.sp * n.obs, n.post.samples))))
         tmp <- array(NA, dim = c(n.post.samples * n.chains, n.sp, J, K.max))
         for (j in 1:(n.obs * n.sp)) {
@@ -1121,7 +1121,7 @@ sfMsAbund <- function(formula, data, inits, priors,
           tmp[, curr.indx[1], curr.indx[2], curr.indx[3]] <- out$mu.samples[j, ]
         }
         out$mu.samples <- tmp[, , order(ord), , drop = FALSE]
-        out$like.samples <- do.call(abind, lapply(out.tmp, function(a) array(a$like.samples, 
+        out$like.samples <- do.call(abind, lapply(out.tmp, function(a) array(a$like.samples,
           								dim = c(n.sp * n.obs, n.post.samples))))
         tmp <- array(NA, dim = c(n.post.samples * n.chains, n.sp, J, K.max))
         for (j in 1:(n.obs * n.sp)) {
@@ -1130,7 +1130,7 @@ sfMsAbund <- function(formula, data, inits, priors,
         }
         out$like.samples <- tmp[, , order(ord), , drop = FALSE]
       }
-      out$w.samples <- do.call(abind, lapply(out.tmp, function(a) array(a$w.samples, 
+      out$w.samples <- do.call(abind, lapply(out.tmp, function(a) array(a$w.samples,
         								dim = c(q, J, n.post.samples))))
       out$w.samples <- out$w.samples[, order(ord), , drop = FALSE]
       out$w.samples <- aperm(out$w.samples, c(3, 1, 2))
@@ -1170,7 +1170,7 @@ sfMsAbund <- function(formula, data, inits, priors,
       tmp <- array(tmp, dim = c(J, K.max, p.abund.re))
       tmp <- tmp[order(ord), , , drop = FALSE]
       out$X.re <- tmp
-      dimnames(out$X.re)[[3]] <- colnames(X.re) 
+      dimnames(out$X.re)[[3]] <- colnames(X.re)
       tmp <- matrix(NA, J * K.max, p.abund.re)
       tmp[names.long, ] <- X.random
       tmp <- array(tmp, dim = c(J, K.max, p.abund.re))
@@ -1192,7 +1192,7 @@ sfMsAbund <- function(formula, data, inits, priors,
       out$coords <- coords[order(ord), ]
       out$cov.model.indx <- cov.model.indx
       out$n.neighbors <- n.neighbors
-      out$dist <- family 
+      out$dist <- family
       out$re.cols <- re.cols
       out$q <- q
       if (p.abund.re > 0) {
