@@ -46,21 +46,21 @@ extern "C" {
                    SEXP chainInfo_r, SEXP sigmaSqIG_r, SEXP family_r, SEXP offset_r);
 
   SEXP spAbundGaussianNNGP(SEXP y_r, SEXP X_r, SEXP coords_r, SEXP XRE_r, SEXP XRandom_r,
-                           SEXP consts_r, SEXP nRELong_r, SEXP m_r, SEXP nnIndx_r, 
+                           SEXP consts_r, SEXP nRELong_r, SEXP m_r, SEXP nnIndx_r,
                            SEXP nnIndxLU_r, SEXP uIndx_r, SEXP uIndxLU_r, SEXP uiIndx_r,
                            SEXP betaStarting_r, SEXP tauSqStarting_r, SEXP sigmaSqMuStarting_r,
-                           SEXP betaStarStarting_r,  
-                           SEXP wStarting_r, SEXP phiStarting_r, 
-                           SEXP sigmaSqStarting_r, SEXP nuStarting_r, 
-                           SEXP betaStarIndx_r, SEXP betaLevelIndx_r, 
-                           SEXP muBeta_r, SEXP SigmaBeta_r, 
-	                   SEXP tauSqA_r, SEXP tauSqB_r, SEXP phiA_r, SEXP phiB_r, 
-                           SEXP sigmaSqA_r, SEXP sigmaSqB_r, SEXP nuA_r, SEXP nuB_r, 
-                           SEXP sigmaSqMuA_r, SEXP sigmaSqMuB_r, 
-                           SEXP tuning_r, SEXP covModel_r, SEXP nBatch_r, 
-                           SEXP batchLength_r, SEXP acceptRate_r, 
-			   SEXP nThreads_r, SEXP verbose_r, 
-                           SEXP nReport_r, SEXP samplesInfo_r, SEXP chainInfo_r, 
+                           SEXP betaStarStarting_r,
+                           SEXP wStarting_r, SEXP phiStarting_r,
+                           SEXP sigmaSqStarting_r, SEXP nuStarting_r,
+                           SEXP betaStarIndx_r, SEXP betaLevelIndx_r,
+                           SEXP muBeta_r, SEXP SigmaBeta_r,
+	                   SEXP tauSqA_r, SEXP tauSqB_r, SEXP phiA_r, SEXP phiB_r,
+                           SEXP sigmaSqA_r, SEXP sigmaSqB_r, SEXP nuA_r, SEXP nuB_r,
+                           SEXP sigmaSqMuA_r, SEXP sigmaSqMuB_r,
+                           SEXP tuning_r, SEXP covModel_r, SEXP nBatch_r,
+                           SEXP batchLength_r, SEXP acceptRate_r,
+			   SEXP nThreads_r, SEXP verbose_r,
+                           SEXP nReport_r, SEXP samplesInfo_r, SEXP chainInfo_r,
 			   SEXP sigmaSqIG_r);
 
   SEXP spAbundNNGPPredict(SEXP coords_r, SEXP J_r, SEXP nObs_r, 
@@ -296,7 +296,7 @@ extern "C" {
 			   SEXP thetaSamples_r, SEXP kappaSamples_r, SEXP lambdaSamples_r, 
 			   SEXP wSamples_r, SEXP betaStarSiteSamples_r, 
 			   SEXP nSamples_r, SEXP covModel_r, SEXP nThreads_r, SEXP verbose_r, 
-			   SEXP nReport_r);
+			   SEXP nReport_r, SEXP sitesLink_r, SEXP sites0Sampled_r);
 
   SEXP DS(SEXP y_r, SEXP X_r, SEXP Xp_r, SEXP XRE_r, SEXP XpRE_r, 
           SEXP XRandom_r, SEXP XpRandom_r, SEXP yMax_r, SEXP offset_r,
